//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
//   FSConnect SDK
//   Copyright  2003 Russel Dirks.  All rights reserved.
//   Email : russdirks@yahoo.ca
//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

#include	<windows.h>
#include <stdio.h>
#include "Tokens.h"
#include "FSConnect.h"

#define StrEnd(pStr) strrchr(pStr, 0)


int APIENTRY WinMain(HINSTANCE hInstance,
                     HINSTANCE hPrevInstance,
                     LPSTR     lpCmdLine,
                     int       nCmdShow)
{

	VAR_TYPE vt;
	UNIVERSAL_VAR uv;
	char szMsg[2000],szVORID[255];
	char FSCVersion[10], FSExeName[30];
	UINT FSVerHi, FSVerLo;
	double Lat, Lon;
	//PCHAR Addr;
	//PVOID FoundAt;
	int res;

	szMsg[0] = 0;
	// get some version information
   res = fscGetVersions(FSCVersion, FSExeName, &FSVerHi, &FSVerLo);
	if (res != 0) {
		sprintf(szMsg, "Error communicating with FSConnect : %i", res);
		MessageBox(NULL, szMsg, "FSConnect", MB_OK | MB_ICONEXCLAMATION);
		return 0;
	} else {
		sprintf(szMsg, "FSConnect version : %s\n", FSCVersion);
		sprintf(StrEnd(szMsg), "Flight Sim Exe : %s\n",FSExeName);
		sprintf(StrEnd(szMsg), "Flight Sim Version : %i.%i.%i.%i\n", 
			FSVerHi >> 16, FSVerHi & 0xFFFF, FSVerLo >> 16, FSVerLo & 0xFFFF);
	}

	// skip error checking from here on

	// ---------------------------------------------------------------------------------
	// fscGetVar examples
	// ---------------------------------------------------------------------------------

	fscGetLatitude(&Lat);
	sprintf(StrEnd(szMsg), "Latitude : %f\n", Lat);

	fscGetLongitude(&Lon);
	sprintf(StrEnd(szMsg), "Longitude : %f\n", Lon);

	fscGetVar(PLANE_ALTITUDE, &uv, &vt);
	sprintf(StrEnd(szMsg), "Plane Altitude : %f\n", uv.n);

	fscGetVar(COM_STBY_FREQUENCY, &uv, &vt);
	sprintf(StrEnd(szMsg), "COM1 Standby Freq : %x\n", uv.d);

	fscGetVar(TRANSPONDER_CODE, &uv, &vt);
	sprintf(StrEnd(szMsg), "Transponder Code : %x\n", uv.o);

	// boolean values seem to come back as an 8 byte double in the "n" parameter,
	// contrary to the SDK documentation
	fscGetVar(AVIONICS_MASTER_SWITCH, &uv, &vt);
	sprintf(StrEnd(szMsg), "Avionics Master Switch : %s\n", uv.n == 0 ? "Off" : "On");
   
   fscGetString(VOR1_IDENTITY, szVORID);
	sprintf(StrEnd(szMsg), "VOR1 Identity : %s\n", szVORID);

	// ---------------------------------------------------------------------------------
	// fscTriggerKeyEvent examples
	// ---------------------------------------------------------------------------------

	// sets throttle to about 50%
	res = fscTriggerKeyEvent(KEY_THROTTLE_SET,8000);
	// set transponder to 1234
	res = fscTriggerKeyEvent(KEY_XPNDR_SET,0x00001234);

	// ---------------------------------------------------------------------------------
	// fscGetXMLVar examples
	// ---------------------------------------------------------------------------------
	double fvalue;
	char svalue[255];
	// retrieve title of user aircraft
	res = fscGetXMLVar("(A:TITLE,string)", 0, 0, svalue);
	sprintf(StrEnd(szMsg), "User Aircraft : %s\n", svalue);
	// another way to get altitude
	res = fscGetXMLVar("(A:PLANE ALTITUDE,feet)", &fvalue, 0, 0);

	// test writing lat/lon into MSFS.  This doesn't work in FS9
	strcat(szMsg, "\n\nTo test writing latitude/longitude into FS, click OK.  The aircraft "
		"will be moved 1/2 minute \nto the north and 1/2 minute to the east.  To bypass the test, click Cancel");


	res = MessageBox(NULL, szMsg, "FSConnect", MB_OKCANCEL | MB_ICONINFORMATION );
	if (res==IDOK) {
		fscSetLatitude(Lat + (1.0 / 120.0));	// move 1/2 minute north 
		fscSetLongitude(Lon + (1.0 / 120.0));	// move 1/2 minute east
	}


	// Here are some examples of calls to some of the "snoop" functions
	
	/*
		// pick a random address within global.dll
	Addr = (PCHAR)0x20943580;	
		// read 4 bytes of data from MSFS's address space
	fscMemRead(Addr, 4, szMsg);
		// write some data into MSFS's address space.  I don't have a clue what 
		// this will do!!
	fscMemWrite(Addr, "11223344");
		// read the same memory address back
	fscMemRead(Addr, 4, szMsg);
		// search a range of address for the value we wrote
	if (0==fscSearchMemRange(Addr - 1000, Addr + 1000, "11223344", &FoundAt)) {
		// found
	} else {
		// not found 
	}
		// search MSFS's entire allocated address space for the address we wrote
		// results will be sent to the indicated file
	fscSearchMemAll("11223344", "c:\\_temp\\res.txt");
	*/

	return 0;
	
}



