Attribute VB_Name = "FSConnect"
'****************************************************************
'   FSConnect SDK v3.00
'   Copyright  2005 Russel Dirks.  All rights reserved.
'   Email : russdirks@yahoo.ca
'****************************************************************
Option Explicit

' these are commands sent to FSConnect
Const GETVAR = 1
Const GETSTRING = 2
Const GETPBIN = 3  ' not implemented
Const SETVAR = 6      ' only Lat/Lon supported at this time, only in FS9
Const MEMREAD = 4
Const MEMWRITE = 5
Const SEARCHMEMRNG = 8
Const SEARCHMEMALL = 9
Const GETVERSIONS = 10
Const GETXMLVAR = 14
Const TRIGGERKEY = 15

Const WM_FSCONNECT = "WM_FSCONNECT"
Const FSC_Class = "FSCONNECT8"
Const MaxAtomStr = 255

' error message used in VB
Const errNoFSC = 1           ' unable to communicate with FSConnect

' error messages returned by FSConnect.dll
Const errNoFSWnd = 4          ' couldn't find FS (not used)
Const errRegWndClass = 5      ' an error occurred registering the FSConnect window class
Const errCreateWnd = 6        ' an error occurred creating the FSConnect window
Const errNotImplemented = 7   ' the command you requested has not been implemented
Const errInvalidData = 8      ' the command you sent contained invalid data
Const errAccessViolation = 9  ' a read/write you requested generated an access violation
Const errNotFound = 11        ' SearchMem function did not find specified data
Const errFSClosing = 16       ' FS is closing

' API functions
Declare Function SendMessage Lib "user32" Alias "SendMessageA" _
   (ByVal hWnd As Long, ByVal wMsg As Long, ByVal wParam As Long, ByVal lParam As Long) As Long
Declare Function FindWindowByClass Lib "user32" Alias "FindWindowA" _
   (ByVal lpClassName As String, ByVal lpWindowName As Any) As Long
Declare Function RegisterWindowMessage Lib "user32" Alias "RegisterWindowMessageA" _
   (ByVal lpString As String) As Long
Declare Function GlobalAddAtom Lib "kernel32" Alias "GlobalAddAtomA" _
   (ByVal lpString As String) As Integer
Declare Function GlobalDeleteAtom Lib "kernel32" (ByVal nAtom As Integer) As Integer
Declare Function GlobalGetAtomName Lib "kernel32" Alias "GlobalGetAtomNameA" _
   (ByVal nAtom As Integer, ByVal lpBuffer As String, ByVal nSize As Long) As Long
Declare Sub CopyMemory Lib "kernel32" Alias "RtlMoveMemory" _
   (Destination As Any, Source As Any, ByVal Length As Long)

Public FSCHWnd As Long     ' window handle to FSConnect
Public FSCMsg As Long   ' window message sent to FSConnect


'**************************************************************************
' The next four functions are high level functions to get/set latitude &
' longitude.  They all return 0 for success, non-zero for error.  See
' defined constants above for meaning of error values
'**************************************************************************
Function fscGetLatitude(lat As Double) As Integer
   Dim v As Variant, res
   On Error GoTo ErrorHandle
   res = fscGetVar(PLANE_LATITUDE, "n", v)
   If res = 0 Then lat = v / 40007000# * 360
   fscGetLatitude = res
   Exit Function

ErrorHandle:
   MsgBox "Error in routine fscGetLatitude!" & vbCr & vbCr & Error, vbCritical
End Function

Function fscGetLongitude(lon As Double) As Integer
   Dim v As Variant, res
   On Error GoTo ErrorHandle
   res = fscGetVar(PLANE_LONGITUDE, "n", v)
   If res = 0 Then lon = v / 281474976710656# * 360
   fscGetLongitude = res
   Exit Function

ErrorHandle:
   MsgBox "Error in routine fscGetLongitude!" & vbCr & vbCr & Error, vbCritical
End Function

Function fscSetLatitude(ByVal lat As Double)
   Dim s As String
   Dim Fake64Bit As Currency
   Dim bitbucket(1 To 8) As Byte
   On Error GoTo ErrorHandle
   lat = (lat / 90#) * (10001750# * 65536# * 65536#)
   Fake64Bit = lat / 10000#
   CopyMemory bitbucket(1), Fake64Bit, 8
   s = BinToHex(bitbucket, 8)
   fscSetLatitude = fscSetVar(PLANE_LATITUDE, s)
   Exit Function

ErrorHandle:
   MsgBox "Error in routine fscSetLatitude!" & vbCr & vbCr & Error, vbCritical
End Function

Function fscSetLongitude(ByVal lon As Double)
   Dim s As String, lng As Long
   Dim Fake64Bit As Currency
   Dim bitbucket(1 To 8) As Byte
   On Error GoTo ErrorHandle
   lon = (lon / 360#) * (65536# * 65536# * 65536# * 65536#)
   Fake64Bit = lon / 10000#
   CopyMemory bitbucket(1), Fake64Bit, 8
   s = BinToHex(bitbucket, 8)
   fscSetVar PLANE_LONGITUDE, s
   Exit Function

ErrorHandle:
   MsgBox "Error in routine fscSetLongitude!" & vbCr & vbCr & Error, vbCritical
End Function


'******************************************************************
' InitFSConnect  - initialization routine
'
' Return Value: zero = failure, non-zero = success
'******************************************************************
Function InitFSConnect() As Integer
   If (FSCMsg <> 0) And (FSCHWnd <> 0) Then
      InitFSConnect = True    ' initialization has aleady been performed
   Else
      FSCMsg = RegisterWindowMessage(WM_FSCONNECT)
      FSCHWnd = FindWindowByClass(FSC_Class, 0&)   ' locate FSConnect
      InitFSConnect = CInt((FSCMsg <> 0) And (FSCHWnd <> 0))
   End If
End Function

'******************************************************************
' fscGetVar  - request data from FSConnect
'
'     Token [in] - data element we want from Flight Simulator
'     VarType [in] - how to interpret data
'     Result [out] - requested data
'     strHex [out] - raw hex data returned by FSConnect (optional parameter)
'     fsVarType [out]  - var type as reported by Flight Simulator (optional parameter)
'
' Return Value: 0 if success, non-zero for error (see defined constants above)
'
' COMMENTS:
' First parameter is a token specifying the data element you want.  See Tokens.bas for the
' full list of possible values.  This corresponds to the enum type GAUGE_TOKEN in
' struct.h, and also to the list found in the document TokenVar.doc, both found in the
' Panels & Gauges SDK.
' The second parameter is a letter indicating what member of the Universal_Var union you think
' the data is stored in.  You get this information from the document TokenVar.doc found in the P&G
' SDK. Possible letters are "n", "b", "e", "f", "p", "d", "o".  Note that when you call this
' function with the "p" parameter, you are only getting a pointer to data, not the data itself.
' If you want the actual data, use fscGetString.
'
' If you are having trouble interpreting the data that comes back, you can make use of the
' optional 4th and 5th parameters to fscGetVar.  strHex is the raw hex string as sent by
' FSConnect.  Note that it is in "memory" byte order. fsVarType is a numeric value indicating
' the type of data you are receiving, as reported by Flight Simulator.  To interpret this value,
' map it onto the enum VAR_TYPE, found in struct.h.
'******************************************************************
Function fscGetVar(Token As Long, VarType As String, Result As Variant, _
                   Optional StrHex As String, Optional fsVarType As Long) As Integer
   Dim chars, i
   Dim dataBin(1 To MaxAtomStr) As Byte
   Dim iAtom As Integer
   Dim d As Double, lng As Long
   
   ' check to make sure things are initialized
   If InitFSConnect() = 0 Then GoTo NoFSC
   ' send request.  FSConnect sends back a handle to an atom, which
   ' contains the data we want
   iAtom = SendMessage(FSCHWnd, FSCMsg, GETVAR, Token)
   If iAtom >= 0 Then GoTo NoData   ' string atoms are always negative
   StrHex = Space(MaxAtomStr)
   chars = GlobalGetAtomName(iAtom, StrHex, MaxAtomStr)  ' retrieve data
   GlobalDeleteAtom iAtom
   StrHex = Left(StrHex, chars)
   HexToBin StrHex, dataBin
   ' pull of the var_type
   CopyMemory fsVarType, dataBin(1), 4
   ' decipher next 8 bytes of data
   Select Case LCase(VarType)
                  ' <description>, <# bytes>, <C++ data type>
      Case "n"    ' a number, 8 bytes, double
         CopyMemory d, dataBin(5), 8
         Result = d
      Case "b"    ' boolean, 4 bytes, int
                  ' data seems to be an 8 byte double, contrary to the SDK
                  ' documentation, so we treat it as an "n" parameter
         CopyMemory d, dataBin(5), 8
         Result = d
      Case "e"    ' enum, 4 bytes, int
         CopyMemory lng, dataBin(5), 4
         Result = lng
      Case "f"    ' flags, 4 bytes, int
         CopyMemory lng, dataBin(5), 4
         Result = lng
      Case "d"    ' binary coded decimal, 4 bytes, unsigned int
         CopyMemory lng, dataBin(5), 4
         Result = lng
      Case "o"    ' binary coded octal, 4 bytes, unsigned int
         CopyMemory lng, dataBin(5), 4
         Result = lng
      Case "p"    ' pointer, 4 bytes, pointer
         CopyMemory lng, dataBin(5), 4
         Result = lng
   End Select
   StrHex = Mid(StrHex, 9) ' lose the first 4 bytes
   fscGetVar = 0 ' success
   Exit Function
   
NoData:
   If iAtom > 0 Then
      fscGetVar = iAtom  ' iAtom contains error code from FSConnect
      Exit Function
   End If   ' else fall through
NoFSC:
   fscGetVar = errNoFSC
   Exit Function
End Function

'******************************************************************
' fscGetString  - request data from FSConnect
'
'     Token [in] - data element we want from Flight Simulator
'     Result [out] - string data returned
'
' Return Value: 0 if success, non-zero for error (see defined constants above)
'
' COMMENTS:
' You will notice that certain data elements listed in TokenVar.doc show a "P"
' in the Universal_Var column. The "P" stands for pointer. Some examples are
' VOR1_IDENTITY and GPS_WP_STRING. What that means is the data stored in the
' Universal_Var buffer is a pointer to the data, not the data itself.
' If you were to use the fscGetVar function above, you would only be getting the
' pointer, which doesn't do you a whole lot of good, since you cannot access the
' memory space of another process.  This function will give you the actual string.
' Only call this function with "P" elements.
'******************************************************************
Function fscGetString(Token, Result As String) As Integer
   Dim chars
   Dim iAtom As Integer
   
   ' check to make sure things are initialized
   If InitFSConnect() = 0 Then GoTo NoFSC
   Result = ""
   ' send request
   iAtom = SendMessage(FSCHWnd, FSCMsg, GETSTRING, Token)
   ' string atoms are always negative
   If iAtom >= 0 Then GoTo NoData
   Result = Space(MaxAtomStr)
   ' retrieve data
   chars = GlobalGetAtomName(iAtom, Result, MaxAtomStr)
   Result = Left(Result, chars)
   GlobalDeleteAtom iAtom
   fscGetString = 0
   Exit Function
   
NoData:
   If iAtom > 0 Then
      fscGetString = iAtom  ' iAtom contains error code from FSConnect
      Exit Function
   End If   ' else fall through
NoFSC:
   fscGetString = errNoFSC
   Exit Function
End Function

'******************************************************************
' fscSetVar  - send data to be written into Flight Simulator.  Currently
'              only latitude and longitude are supported. (FS must be pause
'              or slew mode)
'
'     Token [in]   - data element ID
'     VarData [in] - data to write, in hexadecimal string format,
'                    "memory" byte order
'
' Return Value: 0 if success, non-zero for error (see defined constants above)
'
'******************************************************************
Function fscSetVar(Token As Long, VarData As String) As Integer
   Dim iAtom As Integer, sAtom As String
   
   ' check to make sure things are initialized
   If InitFSConnect() = 0 Then GoTo NoFSC
   sAtom = ToHex(Token, 8) & VarData
   iAtom = GlobalAddAtom(sAtom)
   fscSetVar = SendMessage(FSCHWnd, FSCMsg, SETVAR, iAtom)
   GlobalDeleteAtom iAtom
   Exit Function
   
NoFSC:
   fscSetVar = errNoFSC
   Exit Function
End Function

'******************************************************************
' fscMemRead  - instruct FSConnect to read and return data from a
'               specified address from with Flight Simulator's memory
'               space.
'
'     Addr [in]    - address
'     nBytes [in]  - number of bytes to read (max 127)
'     Result [out] - data returned, in hexadecimal string format,
'                    in "memory" byte order
'
' Return Value: zero if success, non-zero if error
'
'******************************************************************
Function fscMemRead(addr As Long, nBytes As Long, Result As String) As Integer
   Dim iAtomIn As Integer, iAtomOut As Integer, sAtom As String
   Dim i, res, chars
   
   ' check to make sure things are initialized
   If InitFSConnect() = 0 Then GoTo NoFSC
   If nBytes > (MaxAtomStr \ 2) Then GoTo BadParameter
   sAtom = ToHex(addr, 8) & ToHex(nBytes, 8)
   iAtomIn = GlobalAddAtom(sAtom)
   iAtomOut = SendMessage(FSCHWnd, FSCMsg, MEMREAD, iAtomIn)
   ' string atoms are always negative
   If iAtomOut >= 0 Then GoTo NoData
   Result = Space(MaxAtomStr)
   ' retrieve data
   chars = GlobalGetAtomName(iAtomOut, Result, MaxAtomStr)
   Result = Left(Result, chars)
   GlobalDeleteAtom iAtomIn
   GlobalDeleteAtom iAtomOut
   fscMemRead = 0
   Exit Function
   
BadParameter:
   fscMemRead = errInvalidData
   Exit Function
NoData:
   If iAtomOut > 0 Then
      fscMemRead = iAtomOut  ' iAtom contains error code from FSConnect
      Exit Function
   End If   ' else fall through
NoFSC:
   fscMemRead = errNoFSC
   Exit Function
End Function

'******************************************************************
' fscMemWrite  - instruct FSConnect to write data to a specific
'                address in Flight Simulator's memory space.
'
'     Addr [in] - address
'     Data [in] - data to write, in hexadecimal string format (max 247 chars),
'                 in "memory" byte order
'
' Return Value: zero if success, non-zero if error
'
'******************************************************************
Function fscMemWrite(addr As Long, Data As String) As Integer
   Dim dataBin(1 To MaxAtomStr \ 2) As Byte
   Dim iAtom As Integer, sAtom As String
   
   ' check to make sure things are initialized
   If InitFSConnect() = 0 Then GoTo NoFSC
   If Len(Data) > (MaxAtomStr - 8) Then GoTo BadParameter
   sAtom = ToHex(addr, 8) & Data
   iAtom = GlobalAddAtom(sAtom)
   fscMemWrite = SendMessage(FSCHWnd, FSCMsg, MEMWRITE, iAtom)
   GlobalDeleteAtom iAtom
   Exit Function
   
NoFSC:
   fscMemWrite = errNoFSC
   Exit Function
BadParameter:
   fscMemWrite = errInvalidData
   Exit Function
End Function

'******************************************************************
' fscSearchMemRange  - instruct FSConnect to search a range of addresses
'                      in Flight Simulator's memory space for specified data
'
'     StartAddr [in] - Start address of search range
'     EndAddr [in]   - End address of search range
'     SrchData [in]  - Data to search for, in hexadecimal string format,
'                      in "memory" byte order. Should be 2, 4, 8, or 16
'                      bytes long, corresponding to 1, 2, 4, or 8 bytes
'                      of data.
'     ResultsFile [in] - name of file to receive search results
'
' Return Value: 0 if search completed, otherwise error value
'
' Remarks: searching is very quick (1MB takes about a second) provided you limit
' your searching to allocated memory.  If, however, you specify memory
' that has not been allocated, each read will generate an access violation,
' which will slow the search significantly!!
'******************************************************************
Function fscSearchMemRange(startAddr As Long, endAddr As Long, _
                           SrchData As String, ResultsFile As String) As Integer
   Dim iAtomIn As Integer, iAtomOut As Integer, sAtom As String
   Dim chars, sFoundAt As String
   
   ' check to make sure things are initialized
   If InitFSConnect() = 0 Then GoTo NoFSC
   sAtom = ToHex(startAddr, 8) & ToHex(endAddr, 8) & ToHex(Len(SrchData) \ 2, 2) & SrchData
   If ResultsFile = "" Then
      sAtom = sAtom & "00"
   Else
      sAtom = sAtom & ResultsFile
   End If
   iAtomIn = GlobalAddAtom(sAtom)
   fscSearchMemRange = SendMessage(FSCHWnd, FSCMsg, SEARCHMEMRNG, iAtomIn)
   GlobalDeleteAtom iAtomIn
   Exit Function
   
SrchError:
   If iAtomOut > 0 Then
      fscSearchMemRange = iAtomOut
      Exit Function
   End If  ' else fall through
NoFSC:
   fscSearchMemRange = errNoFSC
   Exit Function
End Function

'******************************************************************
' fscSearchMemAll  - instruct FSConnect to search all allocated memory
'                    in Flight Simulator's memory space for specified data
'
'     SrchData [in]  - Data to search for, in hexadecimal string format,
'                      in "memory" byte order. Should be 2, 4, 8, or 16
'                      bytes long, corresponding to 1, 2, 4, or 8 bytes
'                      of data.
'     ResultsFile [in] - name of file to receive search results
'
' Return Value: 0 if search completed, otherwise error value
'
' Remarks: this search takes about 8 seconds on my PIII-600
'******************************************************************
Function fscSearchMemAll(SrchData As String, ResultsFile As String) As Integer
   Dim iAtom As Integer, sAtom As String
   
   ' check to make sure things are initialized
   If InitFSConnect() = 0 Then GoTo NoFSC
   sAtom = ToHex(Len(SrchData) \ 2, 2) & SrchData & ResultsFile
   iAtom = GlobalAddAtom(sAtom)
   fscSearchMemAll = SendMessage(FSCHWnd, FSCMsg, SEARCHMEMALL, iAtom)
   GlobalDeleteAtom iAtom
   Exit Function
   
NoFSC:
   fscSearchMemAll = errNoFSC
   Exit Function
End Function

'******************************************************************
' fscGetVersions  - returns FSConnect version, FS Exe name, and FS Version
'
'     FSCVersion [out] - version of FSConnect.dll
'     FSExeName [out] - exe name of FS (eg, "fs2002.exe")
'     FSVerHi [out] - FS Version number. Code in btnGetData_Click shows how
'                     to interpret this
'     FSVerLo [out] - FS Version number.
'
' Return Value: 0 = success, non-zero = error
'******************************************************************
Function fscGetVersions(FSCVersion As String, FSExeName As String, _
                        FSVerHi As Long, FSVerLo As Long) As Integer
   Dim iAtom As Integer, StrHex As String
   Dim chars
   
   ' check to make sure things are initialized
   If InitFSConnect() = 0 Then GoTo NoFSC
   iAtom = SendMessage(FSCHWnd, FSCMsg, GETVERSIONS, 0)
   If iAtom >= 0 Then GoTo NoData   ' string atoms are always negative
   StrHex = Space(MaxAtomStr)
   chars = GlobalGetAtomName(iAtom, StrHex, MaxAtomStr)  ' retrieve data
   GlobalDeleteAtom iAtom
   StrHex = Left(StrHex, chars)
   GlobalDeleteAtom iAtom
   FSCVersion = Left(StrHex, 5)
   FSVerHi = CLng("&H" & Mid(StrHex, 6, 8))
   FSVerLo = CLng("&H" & Mid(StrHex, 14, 8))
   FSExeName = Mid(StrHex, 22)
   fscGetVersions = 0
   Exit Function
   
NoData:
   If iAtom > 0 Then
      fscGetVersions = iAtom  ' iAtom contains error code from FSConnect
      Exit Function
   End If   ' else fall through
NoFSC:
   fscGetVersions = errNoFSC
   Exit Function
End Function

'-------------------------------------------------------------------
' fscTriggerKeyEvent  - This function exposes the function
'     trigger_key_event. See the Panels & Guages SDK for complete
'     information.  In brief, this function allows you to control
'     the user aircraft, and certain aspects of the sim.  For instance,
'     you can manipulate the flight controls, or set switches on
'     the panel.
'
'     event_id [in]  - Event identifier.  See EventIDs.doc in the Panels
'                      & Guages SDK for complete list.
'     value [in]     - value to set
'
' Return Value: this function returns whatever trigger_key_event
'     returns, which seems to be zero for success.
'-------------------------------------------------------------------
Function fscTriggerKeyEvent(event_id As Long, value As Long) As Integer
   Dim iAtom As Integer, sAtom As String
   
   If InitFSConnect() = 0 Then GoTo NoFSC
   sAtom = ToHex(event_id, 8) & ToHex(value, 8)
   iAtom = GlobalAddAtom(sAtom)
   fscTriggerKeyEvent = SendMessage(FSCHWnd, FSCMsg, TRIGGERKEY, iAtom)
   GlobalDeleteAtom iAtom
   Exit Function
   
NoFSC:
   fscTriggerKeyEvent = errNoFSC
   Exit Function

End Function

'--------------------------------------------------------------------------------
' fscGetXMLVar  - This function exposes the execute_calculator_code function.
'     There is no mention of this function in the SDK, however various people on
'     Avsim and elsewhere have figured out you can pass it an XML expression and it
'     will return the result.
'
'     XML_Expr [in]   - XML expression
'     fvalue [in/out] - pointer to double to receive return value. Optional
'     ivalue [in/out] - pointer to integer to receive return value.  Optional
'     svalue [in/out] - pointer to string buffer to receive return value.  Optional
'
' Return Value: this function returns whatever trigger_key_event
'     returns, which seems to be 1 for success.
'--------------------------------------------------------------------------------
Function fscGetXMLVar(XML_Expr As String, Optional fvalue As Double, _
                      Optional ivalue As Integer, Optional svalue As String) As Integer

   Dim sAtom As String, chars As Integer
   Dim iAtomIn As Integer, iAtomOut As Integer, res As Integer
   Dim dataBin(1 To 8) As Byte

   If InitFSConnect() = 0 Then GoTo NoFSC
   iAtomIn = GlobalAddAtom(XML_Expr)
   iAtomOut = SendMessage(FSCHWnd, FSCMsg, GETXMLVAR, iAtomIn)
   If iAtomOut >= 0 Then GoTo NoData
   sAtom = Space(MaxAtomStr)
   chars = GlobalGetAtomName(iAtomOut, sAtom, MaxAtomStr)
   sAtom = Left(sAtom, chars)
   GlobalDeleteAtom iAtomIn
   GlobalDeleteAtom iAtomOut
   ' unpack the data
   res = CLng("&H" & Mid(sAtom, 1, 8))
   ' unpack the double value
   HexToBin Mid(sAtom, 9, 16), dataBin
   CopyMemory fvalue, dataBin(1), 8
   ivalue = CLng("&H" & Mid(sAtom, 25, 8))
   svalue = Mid(sAtom, 33)
   fscGetXMLVar = res
   Exit Function
   
NoData:
   If iAtomOut > 0 Then
      fscGetXMLVar = iAtomOut  ' iAtom contains error code from FSConnect
      Exit Function
   End If   ' else fall through
NoFSC:
   fscGetXMLVar = errNoFSC
   Exit Function
End Function


'**************************************************************************
' Miscellaneous functions
'**************************************************************************

Function ToHex(var As Long, MinDigits As Integer) As String
   ToHex = Right(String(MinDigits, "0") & Hex(var), MinDigits)
End Function

Function ReverseOrder(s As String) As String
   ' input a string of hexadecimal digits, reverse the byte order
   Dim Result As String, i
   
   Result = ""
   For i = 1 To Len(s) / 2
      Result = Mid(s, i * 2 - 1, 2) & Result
   Next i
   ReverseOrder = Result
End Function

Function BinToHex(BinArray() As Byte, count As Integer) As String
   Dim i As Integer, s As String
   
   s = ""
   For i = 1 To count
      s = s & ToHex(CLng(BinArray(i)), 2)
   Next i
   BinToHex = s
End Function

Function HexToBin(HexStr As String, BinArray() As Byte)
   Dim i As Integer
   
   For i = 1 To Len(HexStr) \ 2
      BinArray(i) = CByte("&H" & Mid(HexStr, i * 2 - 1, 2))
   Next i
End Function

Function StrToHex(s As String) As String
   Dim res As String, i As Integer
   
   res = ""
   For i = 1 To Len(s)
      res = res & ToHex(Asc(Mid(s, i, 1)), 2)
   Next i
   StrToHex = res
End Function

Function HexToStr(sHex As String) As String
   Dim res As String, i As Integer
   
   res = ""
   For i = 1 To Len(sHex) \ 2
      res = res & Chr(CByte("&H" & Mid(sHex, i * 2 - 1, 2)))
   Next i
   HexToStr = res
End Function
