Attribute VB_Name = "Tokens"
'****************************************************************
'   FSConnect SDK v1.00
'   Copyright  2003 Russel Dirks.  All rights reserved.
'   Email : russdirks@yahoo.ca
'****************************************************************
Option Explicit

' these are the data elements available.  This was taken from STRUCT.H of the
' Panels & Guages SDK

Enum GAUGE_TOKEN
   MODULE_VAR_NONE = 0
   TICK18                 '  inc'd at 18hz. used for general purpose timing
   GROUND_ALTITUDE        '  ground level altitude (1/256 meter/unit)
   CLOCK_HOUR             '  local clock time, hours {0..23}
   CLOCK_MINUTE           '  local clock time, minutes {0..59}
   CLOCK_SECOND           '  local clock time, seconds {0..59}
   ZULU_HOUR              '  delta time from GMT
   ZULU_MINUTE            '  delta time from GMT
   ZULU_DAY               '  GMT day of year (1 - 365/366)
   ZULU_YEAR              '  GMT year
   PANEL_LIGHTS           '  TRUE=panel lighting on
   STROBE_LIGHTS          '  TRUE=strobe lights on
   STROBE_FLASH           '  TRUE=strobe flash on model & screen
   PITOT_HEAT             ' TRUE=pitot heat on
   LANDING_LIGHTS            '  TRUE=landing lights on
   SMOKE_ENABLE           '  TRUE=smoke system active
   ADF_FREQUENCY          '  |
   ADF_500_HZ_TUNABLE        ' |  ADF frequency
   ADF_EXTENDED_FREQUENCY    ' |
   ADF_IDENTITY
   ADF_SIGNAL_STRENGTH
   ADF_MORSE_IDENT
   ADF_CARD_RADIAL        ' integer degrees 0-360
   COM_FREQUENCY          '  BCD COM radio freq
   NAV1_FREQUENCY            '  BCD NAV1 radio freq
   NAV1_VOR_RADIAL
   NAV1_MORSE_IDENT
   NAV2_FREQUENCY            '  BCD NAV2 radio freq
   NAV2_VOR_RADIAL
   NAV2_MORSE_IDENT
   DME1_DISPLAY_TYPE         '  FALSE=distance readout,  TRUE=speed in kts readout
   DME1_DISTANCE          '  DME1 distance readout
   DME1_SPEED             '  DME1 speed readout
   DME1_MORSE_IDENT
   DME2_DISPLAY_TYPE         '  FALSE=distance readout,  TRUE=speed in kts readout
   DME2_DISTANCE          '  DME2 distance readout
   DME2_SPEED             '  DME2 speed readout
   DME2_MORSE_IDENT
   TRANSPONDER_CODE       '  Octal Transponder code {0000 - 7777}
   ADF_NEEDLE             ' 16 bit pseudodegrees
   VOR1_NEEDLE            ' +-127 correspond to +-10 if VOR or to +-2.5 if localiser.
   VOR1_GS_NEEDLE            ' +-120 correspond to +-0.7
   VOR1_BACK_COURSE_FLAGS    '  Status of VOR1 (see BC_FLAG_ in FS6DEF.H)
   VOR1_TF_FLAG
   VOR1_GS_FLAG
   VOR1_OBI
   VOR1_CODE
   VOR1_IDENTITY
   VOR1_MAG_VAR
   VOR1_SIGNAL_STRENGTH
   VOR2_NEEDLE
   VOR2_BACK_COURSE_FLAGS    '  Status of VOR2 (see BC_FLAG_ in FS6DEF.H)
   VOR2_TF_FLAG
   VOR2_GS_FLAG
   VOR2_OBI
   VOR2_CODE
   VOR2_IDENTITY
   VOR2_MAG_VAR
   VOR2_SIGNAL_STRENGTH
   VOR2_BEARING_DEGREES
   AIRCRAFT_ON_GROUND        '  TRUE=aircraft is on the ground
   AIRSPEED               ' Airspeed - Indicated or True based on GLOBALP->indicated_aspd
   AIRSPEED_TRUE_CALIBRATE   ' Degrees rotation of the tas calibration card
   BARBER_POLE_ASPD       '  Movable Red-line airspeed  {1/128th knot/unit}
   MACH                '  mach, 64k=3.2 mach (would be better as UIF32)
   VERTICAL_SPEED            '  Velocity Up, vertical speed {1/256th m/sec}
   MACH_MAX_OPERATE
   STALL_WARNING          '  TRUE=5 knots before stall
   OVERSPEED_WARNING         '  TRUE=overspeed warning
   TURN_COORDINATOR_BALL_POS '  turn coordinator ball position {-127..0..127}
   DELTA_HEADING_RATE
   PLANE_LATITUDE            '  current position of our aircraft
   PLANE_LONGITUDE        '  current position of our aircraft
   PLANE_ALTITUDE            '  current position of our aircraft
   ALT_FROM_BAROMETRIC_PRESSURE
   KOHLSMAN_SETTING_MB    '  knob position millibars
   KOHLSMAN_SETTING_HG    '  knob position inches of hg
   PLANE_PITCH_DEGREES
   ATTITUDE_INDICATOR_PITCH_DEGREES
   PLANE_BANK_DEGREES
   ATTITUDE_INDICATOR_BANK_DEGREES
   PLANE_HEADING_DEGREES_MAGNETIC
   MAGNETIC_VAR           '  magnetic north vs. true north angular error
   WHISKEY_COMPASS_DEGREES   ' True degrees
   PLANE_HEADING_DEGREES_GYRO
   GYRO_DRIFT_ERROR
   PLANE_HEADING_DEGREES_TRUE
   AIRCRAFT_AUTOPILOT_AVAILABLE
   AIRCRAFT_FLAPS_AVAILABLE
   AIRCRAFT_STALL_HORN_AVAILABLE
   AIRCRAFT_ENGINE_MIXTURE_AVAILABLE
   AIRCRAFT_CARB_HEAT_AVAILABLE
   AIRCRAFT_SPOILER_AVAILABLE
   AIRCRAFT_IS_TAIL_DRAGGER
   AIRCRAFT_STROBES_AVAILABLE
   AIRCRAFT_PROP_TYPE_AVAILABLE '  PROP_TYPE_FIXED, PROP_TYPE_MANUAL, PROP_TYPE_AUTOMATIC
   AIRCRAFT_TOE_BRAKES_AVAILABLE
   AIRCRAFT_NAV1_AVAILABLE
   AIRCRAFT_NAV2_AVAILABLE
   AIRCRAFT_NAV1_OBS_AVAILABLE
   AIRCRAFT_NAV2_OBS_AVAILABLE
   AIRCRAFT_VOR2_GAUGE_AVAILABLE
   AIRCRAFT_GYRO_DRIFT_AVAILABLE   ' fek: may not be used for bug #2131 but making other changes...build build build
   AUTOPILOT_ACTIVE       '  autopilot master on/off
   AUTOPILOT_WING_LEVELER    '  wing leveler on/off
   AUTOPILOT_NAV1_LOCK    '  nav 1 lock on/off
   AUTOPILOT_HEADING_LOCK    '  heading lock on/off
   AUTOPILOT_HEADING_LOCK_DIR   '  heading lock direction
   AUTOPILOT_ALTITUDE_LOCK   '  altitude lock on/off
   AUTOPILOT_ALTITUDE_LOCK_VAR '  altitude lock altitude in appropriate units
   AUTOPILOT_ATTITUDE_HOLD   '  attitude hold
   AUTOPILOT_GLIDESLOPE_HOLD '  glideslope hold
   AUTOPILOT_APROACH_HOLD    '  approach hold
   AUTOPILOT_BACKCOURSE_HOLD '  backcourse hold
   AUTOPILOT_YAW_DAMPER      '  yaw damper
   AUTOPILOT_AIRSPEED_HOLD   '  airspeed hold
   AUTOPILOT_AIRSPEED_HOLD_VAR '  airspeed hold var
   AUTOPILOT_MACH_HOLD    '  airspeed hold
   AUTOPILOT_MACH_HOLD_VAR   '  airspeed hold var
   AUTOPILOT_VERTICAL_HOLD   '  vertical hold
   AUTOPILOT_VERTICAL_HOLD_VAR '  vertical speed hold var in appropriate units
   AUTOPILOT_ALTITUDE_MANUALLY_TUNABLE
   AUTOPILOT_HEADING_MANUALLY_TUNABLE
   AUTOPILOT_AUTO_THROTTLE_ARM
   AUTOPILOT_TAKEOFF_POWER_ACTIVE
   ENGINE_RPM_HOLD
   ENGINE_CONTROL_SELECT           '  which engine is being controlled
   ENGINE1
   ENGINE1_THROTTLE_LEVER_POS   ' throttle position       (16k = 100% throttle position)
   ENGINE1_PROPELLER_LEVER_POS  ' propeller lever position   (16k = 100% prop setting)
   ENGINE1_MIXTURE_LEVER_POS    ' mixture position        (16k = 100% mixture position)
   ENGINE1_COMBUSTION        ' combustion flag            (combustion = TRUE)
   ENGINE1_STARTER_SWITCH_POS   ' starter switch position
   ENGINE1_MAGNETO_LEFT         ' left magneto status        (activated = 1)
   ENGINE1_MAGNETO_RIGHT        ' right magneto status    (activated = 1)
   ENGINE1_N1_RPM            ' gas producer (RPM)         (16k = 100% RPM)
   ENGINE1_N2_RPM            ' power (RPM)             (16k = 100% RPM)
   ENGINE1_FF_GPH
   ENGINE1_FF_PPH            ' fuel flow PPH
   ENGINE1_FF_PPH_SSL        ' fuel flow (PPH)            (16k = 100%, Standard sea level conditions)
   ENGINE1_TORQUE            ' torque produced ( FT*LBS )
   ENGINE1_ANTI_ICE_SWITCH      ' anti ice switch
   ENGINE1_PRESSURE_RATIO    ' engine pressure ratio      (65k = 6.4)
   ENGINE1_PRESSURE_BUG_POS     ' epr governed engine setting (16k = 100% epr setting)
   ENGINE1_EGT               ' exhaust gas temp (degC)    (16k = 860 deg)
   ENGINE1_EGT_BUG_POS       ' egt governed engine setting (16k = 100% egt setting)
   ENGINE1_CHT               ' cylinder head temperature
   ENGINE1_OIL_TEMPERATURE      ' oil temperature (degC)     (16k = 140 deg)
   ENGINE1_OIL_PRESSURE         ' oil pressure (PSI)         (16k = 55 PSI)
   ENGINE1_OIL_QUANTITY         ' oil quantity            (16k = 100%)
   ENGINE1_HYDRAULIC_PRESSURE   ' hydraulic pressure (PSI)   (16k = 4 psi)
   ENGINE1_HYDRAULIC_QUANTITY   ' hydraulic quantity         (16k = 100%)
   ENGINE1_MANIFOLD_PRESSURE    ' manifold pressure       (65k = 64)
   ENGINE1_ENGINE_VIBRATION     ' oil quantity            (16k = 5)
   ENGINE1_RPM_SCALER        ' *16384 gives actual prop rpm in dx (= 65535 for jets)
   ENGINE1_TURBINE_TEMPERATURE  ' (DegC * 16384)
   ENGINE1_TORQUE_PERCENT       ' (FT/LBS * 16384)
   ENGINE1_FUEL_PRESSURE           ' (PSI * 16384)
   ENGINE1_ELECTRICAL_LOAD         ' (Max Load * 16384)
   ENGINE1_TRANSMISSION_PRESSURE      ' (PSI * 16384)
   ENGINE1_TRANSMISSION_TEMPERATURE   ' (DegC * 16384)
   ENGINE1_ROTOR_RPM               ' (Max 8 16384)
   ENGINE2
   ENGINE2_THROTTLE_LEVER_POS   ' throttle position (0-16384=>0-100%throttle position)
   ENGINE2_PROPELLER_LEVER_POS '   propeller lever position (0-16384=>0-100%prop setting)
   ENGINE2_MIXTURE_LEVER_POS ' mixture position (0-16384=>0-100%mixture position)
   ENGINE2_COMBUSTION        ' combustion flag (combustion = TRUE)
   ENGINE2_STARTER_SWITCH_POS   ' starter switch position
   ENGINE2_MAGNETO_LEFT      ' left magneto status (activated = 1)
   ENGINE2_MAGNETO_RIGHT     ' right magneto status (activated = 1)
   ENGINE2_N1_RPM            ' gas producer RPM (0-16384=>0-100%RPM)
   ENGINE2_N2_RPM            ' power RPM (0-16384=>0-100%RPM)
   ENGINE2_FF_GPH
   ENGINE2_FF_PPH            ' PPH
   ENGINE2_FF_PPH_SSL        ' fuel flow (0-16384=>0-100%)PPH, Standard sea level conditions
   ENGINE2_TORQUE            ' torque produced ( FT*LBS )
   ENGINE2_ANTI_ICE_SWITCH   ' anti ice switch
   ENGINE2_PRESSURE_RATIO    ' engine pressure ratio (0-65536=>0-6.4)
   ENGINE2_PRESSURE_BUG_POS  ' epr governed engine setting (0-16384=>0-100%epr setting)
   ENGINE2_EGT            ' exhaust gas temperature (degC)
   ENGINE2_EGT_BUG_POS    ' egt governed engine setting (0-16384=>0-100%egt setting)
   ENGINE2_CHT            ' cylinder head temperature
   ENGINE2_OIL_TEMPERATURE   ' oil temperature (degC)
   ENGINE2_OIL_PRESSURE      ' oil pressure (PSI)
   ENGINE2_OIL_QUANTITY      ' oil quantity (0-16384 => 0-100%)
   ENGINE2_HYDRAULIC_PRESSURE   ' hydraulic pressure (0-16384 => 0-4 psi)
   ENGINE2_HYDRAULIC_QUANTITY   ' hydraulic quantity (0-16384 => 0-100%)
   ENGINE2_MANIFOLD_PRESSURE ' manifold pressure (0-65536=>0-64)
   ENGINE2_ENGINE_VIBRATION  ' oil quantity (0-16384 => 0-5)
   ENGINE2_RPM_SCALER        ' *16384 gives actual prop rpm in dx (= 65535 for jets)
   ENGINE2_TURBINE_TEMPERATURE     ' (DegC * 16384)
   ENGINE2_TORQUE_PERCENT          ' (FT/LBS * 16384)
   ENGINE2_FUEL_PRESSURE           ' (PSI * 16384)
   ENGINE2_ELECTRICAL_LOAD         ' (Max Load * 16384)
   ENGINE2_TRANSMISSION_PRESSURE      ' (PSI * 16384)
   ENGINE2_TRANSMISSION_TEMPERATURE   ' (DegC * 16384)
   ENGINE2_ROTOR_RPM               ' (Max 8 16384)
   ENGINE3
   ENGINE3_THROTTLE_LEVER_POS   ' throttle position (0-16384=>0-100%throttle position)
   ENGINE3_PROPELLER_LEVER_POS '   propeller lever position (0-16384=>0-100%prop setting)
   ENGINE3_MIXTURE_LEVER_POS ' mixture position (0-16384=>0-100%mixture position)
   ENGINE3_COMBUSTION        ' combustion flag (combustion = TRUE)
   ENGINE3_STARTER_SWITCH_POS   ' starter switch position
   ENGINE3_MAGNETO_LEFT      ' left magneto status (activated = 1)
   ENGINE3_MAGNETO_RIGHT     ' right magneto status (activated = 1)
   ENGINE3_N1_RPM            ' gas producer RPM (0-16384=>0-100%RPM)
   ENGINE3_N2_RPM            ' power RPM (0-16384=>0-100%RPM)
   ENGINE3_FF_GPH
   ENGINE3_FF_PPH            ' fuel flow PPH
   ENGINE3_FF_PPH_SSL        ' fuel flow (0-16384=>0-100%)PPH, Standard sea level conditions
   ENGINE3_TORQUE            ' torque produced ( FT*LBS )
   ENGINE3_ANTI_ICE_SWITCH   ' anti ice switch
   ENGINE3_PRESSURE_RATIO    ' engine pressure ratio (0-65536=>0-6.4)
   ENGINE3_PRESSURE_BUG_POS  ' epr governed engine setting (0-16384=>0-100%epr setting)
   ENGINE3_EGT            ' exhaust gas temperature (degC)
   ENGINE3_EGT_BUG_POS    ' egt governed engine setting (0-16384=>0-100%egt setting)
   ENGINE3_CHT            ' cylinder head temperature
   ENGINE3_OIL_TEMPERATURE   ' oil temperature (degC)
   ENGINE3_OIL_PRESSURE      ' oil pressure (PSI)
   ENGINE3_OIL_QUANTITY      ' oil quantity (0-16384 => 0-100%)
   ENGINE3_HYDRAULIC_PRESSURE   ' hydraulic pressure (0-16384 => 0-4 psi)
   ENGINE3_HYDRAULIC_QUANTITY   ' hydraulic quantity (0-16384 => 0-100%)
   ENGINE3_MANIFOLD_PRESSURE ' manifold pressure (0-65536=>0-64)
   ENGINE3_ENGINE_VIBRATION  ' oil quantity (0-16384 => 0-5)
   ENGINE3_RPM_SCALER        ' *16384 gives actual prop rpm in dx (= 65535 for jets)
   ENGINE3_TURBINE_TEMPERATURE     ' (DegC * 16384)
   ENGINE3_TORQUE_PERCENT          ' (FT/LBS * 16384)
   ENGINE3_FUEL_PRESSURE           ' (PSI * 16384)
   ENGINE3_ELECTRICAL_LOAD         ' (Max Load * 16384)
   ENGINE3_TRANSMISSION_PRESSURE      ' (PSI * 16384)
   ENGINE3_TRANSMISSION_TEMPERATURE   ' (DegC * 16384)
   ENGINE3_ROTOR_RPM               ' (Max 8 16384)
   ENGINE4
   ENGINE4_THROTTLE_LEVER_POS   ' throttle position (0-16384=>0-100%throttle position)
   ENGINE4_PROPELLER_LEVER_POS '   propeller lever position (0-16384=>0-100%prop setting)
   ENGINE4_MIXTURE_LEVER_POS ' mixture position (0-16384=>0-100%mixture position)
   ENGINE4_COMBUSTION        ' combustion flag (combustion = TRUE)
   ENGINE4_STARTER_SWITCH_POS   ' starter switch position
   ENGINE4_MAGNETO_LEFT      ' left magneto status (activated = 1)
   ENGINE4_MAGNETO_RIGHT     ' right magneto status (activated = 1)
   ENGINE4_N1_RPM            ' gas producer RPM (0-16384=>0-100%RPM)
   ENGINE4_N2_RPM            ' power RPM (0-16384=>0-100%RPM)
   ENGINE4_FF_GPH
   ENGINE4_FF_PPH            ' fuel flow PPH
   ENGINE4_FF_PPH_SSL        ' fuel flow (0-16384=>0-100%)PPH, Standard sea level conditions
   ENGINE4_TORQUE            ' torque produced ( FT*LBS )
   ENGINE4_ANTI_ICE_SWITCH   ' anti ice switch
   ENGINE4_PRESSURE_RATIO    ' engine pressure ratio (0-65536=>0-6.4)
   ENGINE4_PRESSURE_BUG_POS  ' epr governed engine setting (0-16384=>0-100%epr setting)
   ENGINE4_EGT            ' exhaust gas temperature (degC)
   ENGINE4_EGT_BUG_POS    ' egt governed engine setting (0-16384=>0-100%egt setting)
   ENGINE4_CHT            ' cylinder head temperature
   ENGINE4_OIL_TEMPERATURE   ' oil temperature (degC)
   ENGINE4_OIL_PRESSURE      ' oil pressure (PSI)
   ENGINE4_OIL_QUANTITY      ' oil quantity (0-16384 => 0-100%)
   ENGINE4_HYDRAULIC_PRESSURE   ' hydraulic pressure (0-16384 => 0-4 psi)
   ENGINE4_HYDRAULIC_QUANTITY   ' hydraulic quantity (0-16384 => 0-100%)
   ENGINE4_MANIFOLD_PRESSURE ' manifold pressure (0-65536=>0-64)
   ENGINE4_ENGINE_VIBRATION  ' oil quantity (0-16384 => 0-5)
   ENGINE4_RPM_SCALER        ' *16384 gives actual prop rpm in dx (= 65535 for jets)
   ENGINE4_TURBINE_TEMPERATURE     ' (DegC * 16384)
   ENGINE4_TORQUE_PERCENT          ' (FT/LBS * 16384)
   ENGINE4_FUEL_PRESSURE           ' (PSI * 16384)
   ENGINE4_ELECTRICAL_LOAD         ' (Max Load * 16384)
   ENGINE4_TRANSMISSION_PRESSURE      ' (PSI * 16384)
   ENGINE4_TRANSMISSION_TEMPERATURE   ' (DegC * 16384)
   ENGINE4_ROTOR_RPM               ' (Max 8 16384)
   NUMBER_OF_ENGINES         '  1=single 2=twin ...
   PROP_ADVANCE_SELECTION    '  0=fixed 1=optimal 2=manual
   THROTTLE_LOWER_LIMIT      '  set by sim for thrust reversers
   OIL_QUANTITY_TOTAL        '  0..7fff (8 qt.)
   SYSTEMS_AVAILABLE
   INSTRUMENTS_AVAILABLE
   PP_ADF                 '  partial panel variables
   PP_AIR
   PP_ALTIM
   PP_ATTITUDE
   PP_COM
   PP_COMPASS
   PP_ELECT               ' there is no electricity in panels circuit
   PP_ENGINE
   PP_FUEL_IND
   PP_HEADING
   PP_VERT_VEL
   PP_XPNDR
   PP_NAV
   PP_PITOT
   PP_TURN_COORD
   PP_VACUUM
   FUEL_TANK_CENTER_LEVEL
   FUEL_TANK_CENTER_CAPACITY
   FUEL_TANK_LEFT_MAIN_LEVEL
   FUEL_TANK_LEFT_MAIN_CAPACITY
   FUEL_TANK_LEFT_AUX_LEVEL
   FUEL_TANK_LEFT_AUX_CAPACITY
   FUEL_TANK_LEFT_TIP_LEVEL
   FUEL_TANK_LEFT_TIP_CAPACITY
   FUEL_TANK_RIGHT_MAIN_LEVEL
   FUEL_TANK_RIGHT_MAIN_CAPACITY
   FUEL_TANK_RIGHT_AUX_LEVEL
   FUEL_TANK_RIGHT_AUX_CAPACITY
   FUEL_TANK_RIGHT_TIP_LEVEL
   FUEL_TANK_RIGHT_TIP_CAPACITY
   FUEL_QUANTITY_RIGHT    ' Total Gallons
   FUEL_QUANTITY_LEFT        ' Total Gallons
   FUEL_QUANTITY_CENTER      ' Total Gallons
   FUEL_WEGHT_PER_GALLON     '  in pounds I.F  (6 lbs/gal = 1536)
   FUEL_TANK_SELECTOR        '  see FUEL_TANK_SELECTOR_ enum values
   CROSS_FEED_SELECTOR    ' OFF, LEFT_TO_RIGHT, or RIGHT_TO_LEFT

   OBSOLETE_YOKE_POS_Y    ' use ELEVATOR_DEFLECTION
   OBSOLETE_YOKE_IND_Y    ' use ELEVATOR_DEFLECTION
   OBSOLETE_YOKE_POS_X    ' use AILERON_DEFLECTION
   OBSOLETE_YOKE_IND_X    ' use AILERON_DEFLECTION
   OBSOLETE_AILERON_POS      ' use AILERON_DEFLECTION
   OBSOLETE_RUDDER_PEDAL_POS ' use RUDDER_DEFLECTION
   OBSOLETE_RUDDER_PEDAL_IND ' use RUDDER_DEFLECTION
   OBSOLETE_RUDDER_POS    ' use RUDDER_DEFLECTION
   OBSOLETE_ELEVATOR_POS     ' use ELEVATOR_DEFLECTION
   OBSOLETE_ELEVATOR_TRIM_POS   ' use ELEVATOR_TRIM
   OBSOLETE_ELEVATOR_TRIM_IND   ' use ELEVATOR_TRIM

   BRAKES_LEFT_POS        '  0=off 32k=full brakes
   BRAKES_RIGHT_POS       '  0=off 32k=full brakes
   BRAKE_IND              '  0=off 16k=full brakes
   PARKING_BRAKE_POS         '  0=off 32k=full   parking brakes
   SPOILERS_ARMED
   SPOILERS_HANDLE_POS
   SPOILERS_POS_LEFT
   SPOILERS_POS_RIGHT
   FLAPS_HANDLE_POS
   FLAPS_POS_LEFT
   FLAPS_POS_RIGHT
   GEAR_HANDLE_POS
   GEAR_POS_NOSE
   GEAR_POS_LEFT
   GEAR_POS_RIGHT
   DISPLAY_UNITS          '  english vs. metric system
   SIM_SPEED              '  time dilation factor for sim equations
   ZOOM_FACTOR            ' zoom value of current window in real units
   REALISM_SENSE
   REALISM_SYSTEMS
   RELIABILITY_SENSE         '  0 = unreliable - 100 = totally reliable
   AMBIENT_TEMP_DEGREES_C    '
   AMBIENT_PRES_MBAR         '  Millibars * 16
   AMBIENT_WIND_VEL       '
   AMBIENT_WIND_DIR       '
   AMBIENT_WINDE          '  MPS x(east) wind component
   AMBIENT_WINDN          '  MPS z(up) wind component
   AMBIENT_WINDA          '  MPS y(north) wind component
   BAROMETRIC_PRESSURE    ' barometric pressure experienced
   ANGLE_OF_ATTACK_INDICATOR
   TOTAL_AIR_TEMP
   G_FORCE
   CHARGING_AMPS          '  charging system amps - 1 amp=65535
   SUCTION_PRESSURE       ' in hg
   MARKER_BEACON_STATE    ' 0=no beacon, 1=outer, 2=middle, 3=inner
   CURRENT_DME            '  DMECUR_DME1 or DMECUR_DME2
   ' **********  New VARS for Combat Flight Simulator 1.0 ***************
   PANEL_STATE_FLAGS
   GET_GUN_AMMO
   GET_CANNON_AMMO
   GET_ROCKET_AMMO
   GET_BOMB_AMMO
   ENGINE_PRIMER          ' 0.0 -> 1.0 == in -> out
   COWL_FLAPS             ' 0.0 -> 1.0 == closed -> open
   MASTER_ALTERNATOR         ' 0.0 -> 1.0 == off -> on
   MASTER_BATTERY            ' 0.0 -> 1.0 == off -> on
   CARB_HEAT              ' 0.0 -> 1.0 == off -> on
   FLIGHT_TIME            ' in 1/10 of hours
   FUEL_PUMP              ' 0.0 -> 1.0 == off -> on
   BEACON_LIGHTS          ' 0.0 -> 1.0 == off -> on
   TAXI_LIGHTS            ' 0.0 -> 1.0 == off -> on
   RADIO_STACK_VISIBLE    ' 0.0 -> 1.0 == off -> on
   HORIZON_BAR_OFFSET        ' -10 deg to + 10 deg
   CURRENT_DME_DISTANCE
   CURRENT_DME_SPEED
   CURRENT_DME_MIN
   WARNING_FUEL
   WARNING_FUEL_L
   WARNING_FUEL_R
   WARNING_VACUUM
   WARNING_VACUUM_L
   WARNING_VACUUM_R
   WARNING_OIL_PSI
   WARNING_VOLTAGE
   FUEL_TANK_CENTER2_LEVEL
   FUEL_TANK_CENTER2_CAPACITY
   FUEL_QUANTITY_CENTER2                       ' Total Gallons
   TOTAL_FUEL_QUANTITY_GALLONS
   SELECTED_FUEL_QUANTITY_GALLONS
   SELECTED_FUEL_QUANTITY_LITERS
   SELECTED_FUEL_QUANTITY_PERCENT
   RECIP_ENGINE1_ENGINE_RPM
   RECIP_ENGINE1_MANIFOLD_PRESSURE
   RECIP_ENGINE1_THROTTLE_LEVER_POS
   RECIP_ENGINE1_MIXTURE_LEVER_POS
   RECIP_ENGINE1_PROP_LEVER_POS
   RECIP_ENGINE1_COWL_FLAP_POS                '0 = closed, 1 = open
   RECIP_ENGINE1_CARB_HEAT_POS                '0 = off, 1 = on
   RECIP_ENGINE1_ALTERNATE_AIR_POS            '0 = closed, 1 = off
   RECIP_ENGINE1_COOLANT_RESERVOIR_PCT
   RECIP_ENGINE1_LEFT_MAG
   RECIP_ENGINE1_RIGHT_MAG
   RECIP_ENGINE1_STARTER
   RECIP_ENGINE1_BRAKE_POWER                  'power delivered to the shaft
   RECIP_ENGINE1_SHAFT_TORQUE                 'torque delivered to the shaft
   RECIP_ENGINE1_PROP_TORQUE                  'torque required by prop
   RECIP_ENGINE1_STARTER_TORQUE               'torque applied by   starter
   RECIP_ENGINE1_COMBUSTION                   'combustion flag
   RECIP_ENGINE1_TURBOCHARGER_FAILED
   RECIP_ENGINE1_EMERGENCY_BOOST_ACTIVE       'like WEP in the P51
   RECIP_ENGINE1_EMERGENCY_BOOST_ELAPSED_TIME 'how long emergency has been active
   RECIP_ENGINE1_WASTEGATE_POS                'position of wastegate controller 1=closed (full boost), 0=open (no boost)
   RECIP_ENGINE1_PROP_BETA                    'blade angle (relative to plane of rotation)
   RECIP_ENGINE1_THRUST                       'lbs
   RECIP_ENGINE1_EGT_DEGR                     'EGT degrees Rankine
   RECIP_ENGINE1_TIT_DEGR                     'Turbine Inlet Temperature degrees Rankine
   RECIP_ENGINE1_CHT_DEGR                     'CHT degrees Rankine
   RECIP_ENGINE1_OIL_TEMP_DEGR                'Oil Temperature degrees Rankine
   RECIP_ENGINE1_RADIATOR_DEGR                'Radiator temperature
   RECIP_ENGINE1_OIL_PRESS_PSF                'Oil Pressure lbs/sqft
   RECIP_ENGINE1_OIL_LEAK_PCT                 'Percent Oil leaked
   RECIP_ENGINE1_FUEL_AVAILABLE               'Fuel available to engine?
   RECIP_ENGINE1_FUELFLOW_PPH                 'Fuel flow in lbs/hr
   RECIP_ENGINE1_TANK_SELECTOR                'Fuel tank selector
   RECIP_ENGINE1_TANKS_USED                   'Fuel tanks used
   RECIP_ENGINE1_NUMBER_OF_TANKS_USED         'Number of fuel tanks used
   RECIP_ENGINE1_FUEL_PRESSURE_PSF            'Fuel pressure in lbs/sqft
   RECIP_ENGINE1_COMBUSTION_SOUND_PCT         'Percent of Sound (0 - 1)
   RECIP_ENGINE1_INDUCED_VELOCITY             'fps, velocity induced by prop
   RECIP_ENGINE1_DAMAGE_PERCENT               '0-100%
   RECIP_ENGINE2_ENGINE_RPM
   RECIP_ENGINE2_MANIFOLD_PRESSURE
   RECIP_ENGINE2_THROTTLE_LEVER_POS
   RECIP_ENGINE2_MIXTURE_LEVER_POS
   RECIP_ENGINE2_PROP_LEVER_POS
   RECIP_ENGINE2_COWL_FLAP_POS                '0 = closed, 1 = open
   RECIP_ENGINE2_CARB_HEAT_POS                '0 = off, 1 = on
   RECIP_ENGINE2_ALTERNATE_AIR_POS            '0 = closed, 1 = off
   RECIP_ENGINE2_COOLANT_RESERVOIR_PCT
   RECIP_ENGINE2_LEFT_MAG
   RECIP_ENGINE2_RIGHT_MAG
   RECIP_ENGINE2_STARTER
   RECIP_ENGINE2_BRAKE_POWER                  'power delivered to the shaft
   RECIP_ENGINE2_SHAFT_TORQUE                 'torque delivered to the shaft
   RECIP_ENGINE2_PROP_TORQUE                  'torque required by prop
   RECIP_ENGINE2_STARTER_TORQUE               'torque applied by   starter
   RECIP_ENGINE2_COMBUSTION                   'combustion flag
   RECIP_ENGINE2_TURBOCHARGER_FAILED
   RECIP_ENGINE2_EMERGENCY_BOOST_ACTIVE       'like WEP in the P51
   RECIP_ENGINE2_EMERGENCY_BOOST_ELAPSED_TIME 'how long emergency has been active
   RECIP_ENGINE2_WASTEGATE_POS                'position of wastegate controller 1=closed (full boost), 0=open (no boost)
   RECIP_ENGINE2_PROP_BETA                    'blade angle (relative to plane of rotation)
   RECIP_ENGINE2_THRUST                       'lbs
   RECIP_ENGINE2_EGT_DEGR                     'EGT degrees Rankine
   RECIP_ENGINE2_TIT_DEGR                     'Turbine Inlet Temperature degrees Rankine
   RECIP_ENGINE2_CHT_DEGR                     'CHT degrees Rankine
   RECIP_ENGINE2_OIL_TEMP_DEGR                'Oil Temperature degrees Rankine
   RECIP_ENGINE2_RADIATOR_DEGR                'Radiator temperature
   RECIP_ENGINE2_OIL_PRESS_PSF                'Oil Pressure lbs/sqft
   RECIP_ENGINE2_OIL_LEAK_PCT                 'Percent Oil leaked
   RECIP_ENGINE2_FUEL_AVAILABLE               'Fuel available to engine?
   RECIP_ENGINE2_FUELFLOW_PPH                 'Fuel flow in lbs/hr
   RECIP_ENGINE2_TANK_SELECTOR                'Fuel tank selector
   RECIP_ENGINE2_TANKS_USED                   'Fuel tanks used
   RECIP_ENGINE2_NUMBER_OF_TANKS_USED         'Number of fuel tanks used
   RECIP_ENGINE2_FUEL_PRESSURE_PSF            'Fuel pressure in lbs/sqft
   RECIP_ENGINE2_COMBUSTION_SOUND_PCT         'Percent of Sound (0 - 1)
   RECIP_ENGINE2_INDUCED_VELOCITY             'fps, velocity induced by prop
   RECIP_ENGINE2_DAMAGE_PERCENT               '0-100%
   RECIP_ENGINE3_ENGINE_RPM
   RECIP_ENGINE3_MANIFOLD_PRESSURE
   RECIP_ENGINE3_THROTTLE_LEVER_POS
   RECIP_ENGINE3_MIXTURE_LEVER_POS
   RECIP_ENGINE3_PROP_LEVER_POS
   RECIP_ENGINE3_COWL_FLAP_POS                '0 = closed, 1 = open
   RECIP_ENGINE3_CARB_HEAT_POS                '0 = off, 1 = on
   RECIP_ENGINE3_ALTERNATE_AIR_POS            '0 = closed, 1 = off
   RECIP_ENGINE3_COOLANT_RESERVOIR_PCT
   RECIP_ENGINE3_LEFT_MAG
   RECIP_ENGINE3_RIGHT_MAG
   RECIP_ENGINE3_STARTER
   RECIP_ENGINE3_BRAKE_POWER                  'power delivered to the shaft
   RECIP_ENGINE3_SHAFT_TORQUE                 'torque delivered to the shaft
   RECIP_ENGINE3_PROP_TORQUE                  'torque required by prop
   RECIP_ENGINE3_STARTER_TORQUE               'torque applied by   starter
   RECIP_ENGINE3_COMBUSTION                   'combustion flag
   RECIP_ENGINE3_TURBOCHARGER_FAILED
   RECIP_ENGINE3_EMERGENCY_BOOST_ACTIVE       'like WEP in the P51
   RECIP_ENGINE3_EMERGENCY_BOOST_ELAPSED_TIME 'how long emergency has been active
   RECIP_ENGINE3_WASTEGATE_POS                'position of wastegate controller 1=closed (full boost), 0=open (no boost)
   RECIP_ENGINE3_PROP_BETA                    'blade angle (relative to plane of rotation)
   RECIP_ENGINE3_THRUST                       'lbs
   RECIP_ENGINE3_EGT_DEGR                     'EGT degrees Rankine
   RECIP_ENGINE3_TIT_DEGR                     'Turbine Inlet Temperature degrees Rankine
   RECIP_ENGINE3_CHT_DEGR                     'CHT degrees Rankine
   RECIP_ENGINE3_OIL_TEMP_DEGR                'Oil Temperature degrees Rankine
   RECIP_ENGINE3_RADIATOR_DEGR                'Radiator temperature
   RECIP_ENGINE3_OIL_PRESS_PSF                'Oil Pressure lbs/sqft
   RECIP_ENGINE3_OIL_LEAK_PCT                 'Percent Oil leaked
   RECIP_ENGINE3_FUEL_AVAILABLE               'Fuel available to engine?
   RECIP_ENGINE3_FUELFLOW_PPH                 'Fuel flow in lbs/hr
   RECIP_ENGINE3_TANK_SELECTOR                'Fuel tank selector
   RECIP_ENGINE3_TANKS_USED                   'Fuel tanks used
   RECIP_ENGINE3_NUMBER_OF_TANKS_USED         'Number of fuel tanks used
   RECIP_ENGINE3_FUEL_PRESSURE_PSF            'Fuel pressure in lbs/sqft
   RECIP_ENGINE3_COMBUSTION_SOUND_PCT         'Percent of Sound (0 - 1)
   RECIP_ENGINE3_INDUCED_VELOCITY             'fps, velocity induced by prop
   RECIP_ENGINE3_DAMAGE_PERCENT               '0-100%
   RECIP_ENGINE4_ENGINE_RPM
   RECIP_ENGINE4_MANIFOLD_PRESSURE
   RECIP_ENGINE4_THROTTLE_LEVER_POS
   RECIP_ENGINE4_MIXTURE_LEVER_POS
   RECIP_ENGINE4_PROP_LEVER_POS
   RECIP_ENGINE4_COWL_FLAP_POS                '0 = closed, 1 = open
   RECIP_ENGINE4_CARB_HEAT_POS                '0 = off, 1 = on
   RECIP_ENGINE4_ALTERNATE_AIR_POS            '0 = closed, 1 = off
   RECIP_ENGINE4_COOLANT_RESERVOIR_PCT
   RECIP_ENGINE4_LEFT_MAG
   RECIP_ENGINE4_RIGHT_MAG
   RECIP_ENGINE4_STARTER
   RECIP_ENGINE4_BRAKE_POWER                  'power delivered to the shaft
   RECIP_ENGINE4_SHAFT_TORQUE                 'torque delivered to the shaft
   RECIP_ENGINE4_PROP_TORQUE                  'torque required by prop
   RECIP_ENGINE4_STARTER_TORQUE               'torque applied by   starter
   RECIP_ENGINE4_COMBUSTION                   'combustion flag
   RECIP_ENGINE4_TURBOCHARGER_FAILED
   RECIP_ENGINE4_EMERGENCY_BOOST_ACTIVE       'like WEP in the P51
   RECIP_ENGINE4_EMERGENCY_BOOST_ELAPSED_TIME 'how long emergency has been active
   RECIP_ENGINE4_WASTEGATE_POS                'position of wastegate controller 1=closed (full boost), 0=open (no boost)
   RECIP_ENGINE4_PROP_BETA                    'blade angle (relative to plane of rotation)
   RECIP_ENGINE4_THRUST                       'lbs
   RECIP_ENGINE4_EGT_DEGR                     'EGT degrees Rankine
   RECIP_ENGINE4_TIT_DEGR                     'Turbine Inlet Temperature degrees Rankine
   RECIP_ENGINE4_CHT_DEGR                     'CHT degrees Rankine
   RECIP_ENGINE4_OIL_TEMP_DEGR                'Oil Temperature degrees Rankine
   RECIP_ENGINE4_RADIATOR_DEGR                'Radiator temperature
   RECIP_ENGINE4_OIL_PRESS_PSF                'Oil Pressure lbs/sqft
   RECIP_ENGINE4_OIL_LEAK_PCT                 'Percent Oil leaked
   RECIP_ENGINE4_FUEL_AVAILABLE               'Fuel available to engine?
   RECIP_ENGINE4_FUELFLOW_PPH                 'Fuel flow in lbs/hr
   RECIP_ENGINE4_TANK_SELECTOR                'Fuel tank selector
   RECIP_ENGINE4_TANKS_USED                   'Fuel tanks used
   RECIP_ENGINE4_NUMBER_OF_TANKS_USED         'Number of fuel tanks used
   RECIP_ENGINE4_FUEL_PRESSURE_PSF            'Fuel pressure in lbs/sqft
   RECIP_ENGINE4_COMBUSTION_SOUND_PCT         'Percent of Sound (0 - 1)
   RECIP_ENGINE4_INDUCED_VELOCITY             'fps, velocity induced by prop
   RECIP_ENGINE4_DAMAGE_PERCENT               '0-100%
   FUEL_QUANTITY_CENTER3                      'Total Gallons
   SCORE_STRING_QUICK_COMBAT
   SCORE_STRING_MULTIPLAYER
   IS_MULTIPLAYER_TEAM_COMBAT
   ' **********  New VARS for Flight Simulator 7.0 ***************
   VOR1_BEARING_DEGREES
   FORWARD_GROUND_VELOCITY               ' in ft/sec
   SIDE_GROUND_VELOCITY                  ' in ft/sec
   VERTICAL_GROUND_VELOCITY              ' in ft/sec
   NORTH_VELOCITY                        ' in ft/sec
   EAST_VELOCITY                      ' in ft/sec
   VERTICAL_VELOCITY                     ' in ft/sec
   CLOCK_TOTAL_SECONDS          '  local clock time, seconds since midnight
   GENERAL_ENGINE1_THROTTLE_LEVER_POS
   GENERAL_ENGINE1_PROPELLER_LEVER_POS
   GENERAL_ENGINE1_MIXTURE_LEVER_POS
   GENERAL_ENGINE1_OIL_TEMP
   GENERAL_ENGINE1_OIL_PRES
   GENERAL_ENGINE1_STARTER
   GENERAL_ENGINE1_FAILURE
   GENERAL_ENGINE1_GENERATOR_SWITCH
   GENERAL_ENGINE1_GENERATOR_ACTIVE
   GENERAL_ENGINE1_EGT
   GENERAL_ENGINE2_THROTTLE_LEVER_POS
   GENERAL_ENGINE2_PROPELLER_LEVER_POS
   GENERAL_ENGINE2_MIXTURE_LEVER_POS
   GENERAL_ENGINE2_OIL_TEMP
   GENERAL_ENGINE2_OIL_PRES
   GENERAL_ENGINE2_STARTER
   GENERAL_ENGINE2_FAILURE
   GENERAL_ENGINE2_GENERATOR_SWITCH
   GENERAL_ENGINE2_GENERATOR_ACTIVE
   GENERAL_ENGINE2_EGT
   GENERAL_ENGINE3_THROTTLE_LEVER_POS
   GENERAL_ENGINE3_PROPELLER_LEVER_POS
   GENERAL_ENGINE3_MIXTURE_LEVER_POS
   GENERAL_ENGINE3_OIL_TEMP
   GENERAL_ENGINE3_OIL_PRES
   GENERAL_ENGINE3_STARTER
   GENERAL_ENGINE3_FAILURE
   GENERAL_ENGINE3_GENERATOR_SWITCH
   GENERAL_ENGINE3_GENERATOR_ACTIVE
   GENERAL_ENGINE3_EGT
   GENERAL_ENGINE4_THROTTLE_LEVER_POS
   GENERAL_ENGINE4_PROPELLER_LEVER_POS
   GENERAL_ENGINE4_MIXTURE_LEVER_POS
   GENERAL_ENGINE4_OIL_TEMP
   GENERAL_ENGINE4_OIL_PRES
   GENERAL_ENGINE4_STARTER
   GENERAL_ENGINE4_FAILURE
   GENERAL_ENGINE4_GENERATOR_SWITCH
   GENERAL_ENGINE4_GENERATOR_ACTIVE
   GENERAL_ENGINE4_EGT
   NAV1_COMMNAV_TEST
   NAV2_COMMNAV_TEST
   COM1_AUTOSWITCH_ON
   NAV1_AUTOSWITCH_ON
   COM2_AUTOSWITCH_ON
   NAV2_AUTOSWITCH_ON
   ELAPSED_SECONDS
   G_FORCE_MAXIMUM
   G_FORCE_MINIMUM
   ENGINE_WORKING_TIME
   ENGINE1_MAX_RPM
   ENGINE2_MAX_RPM
   ENGINE3_MAX_RPM
   ENGINE4_MAX_RPM
   ATTITUDE_BARS_POSITION
   RAD_INS_SWITCH      ' used in concorde only
   RADIO_HEIGHT        ' meters
   DECISION_HEIGHT     ' meters
   LOW_HEIGHT_WARNING     ' boolean
   COM_STBY_FREQUENCY     ' BCD; same as COM_FREQUENCY
   COM_RADIO_25_KHZ_TUNABLE ' Boolean

   NAV_LIGHTS
   LOGO_LIGHTS
   WING_LIGHTS
   RECOGNITION_LIGHTS

   RADIO_MORSE_IDENT_STATES


   TURB_ENGINE_1_N1
   TURB_ENGINE_1_N2
   TURB_ENGINE_1_CORRECTED_N1
   TURB_ENGINE_1_CORRECTED_N2
   TURB_ENGINE_1_CORRECTED_FF
   TURB_ENGINE_1_PCT_MAX_TORQUE
   TURB_ENGINE_1_EPR
   TURB_ENGINE_1_ITT
   TURB_ENGINE_1_AFTERBURNER
   TURB_ENGINE_1_JET_THRUST
   TURB_ENGINE_1_BLEEDAIRPSI
   TURB_ENGINE_1_TANK_SELECTOR
   TURB_ENGINE_1_TANKS_USED
   TURB_ENGINE_1_NUMBER_TANKS
   TURB_ENGINE_1_FUELFLOW_PPH
   TURB_ENGINE_1_FUEL_AVAILABLE
   TURB_ENGINE_1_PCT_AREA
   TURB_ENGINE_1_PCT_REVERSER
   TURB_ENGINE_1_VIBRATION

   TURB_ENGINE_2_N1
   TURB_ENGINE_2_N2
   TURB_ENGINE_2_CORRECTED_N1
   TURB_ENGINE_2_CORRECTED_N2
   TURB_ENGINE_2_CORRECTED_FF
   TURB_ENGINE_2_PCT_MAX_TORQUE
   TURB_ENGINE_2_EPR
   TURB_ENGINE_2_ITT
   TURB_ENGINE_2_AFTERBURNER
   TURB_ENGINE_2_JET_THRUST
   TURB_ENGINE_2_BLEEDAIRPSI
   TURB_ENGINE_2_TANK_SELECTOR
   TURB_ENGINE_2_TANKS_USED
   TURB_ENGINE_2_NUMBER_TANKS
   TURB_ENGINE_2_FUELFLOW_PPH
   TURB_ENGINE_2_FUEL_AVAILABLE
   TURB_ENGINE_2_PCT_AREA
   TURB_ENGINE_2_PCT_REVERSER
   TURB_ENGINE_2_VIBRATION

   TURB_ENGINE_3_N1
   TURB_ENGINE_3_N2
   TURB_ENGINE_3_CORRECTED_N1
   TURB_ENGINE_3_CORRECTED_N2
   TURB_ENGINE_3_CORRECTED_FF
   TURB_ENGINE_3_PCT_MAX_TORQUE
   TURB_ENGINE_3_EPR
   TURB_ENGINE_3_ITT
   TURB_ENGINE_3_AFTERBURNER
   TURB_ENGINE_3_JET_THRUST
   TURB_ENGINE_3_BLEEDAIRPSI
   TURB_ENGINE_3_TANK_SELECTOR
   TURB_ENGINE_3_TANKS_USED
   TURB_ENGINE_3_NUMBER_TANKS
   TURB_ENGINE_3_FUELFLOW_PPH
   TURB_ENGINE_3_FUEL_AVAILABLE
   TURB_ENGINE_3_PCT_AREA
   TURB_ENGINE_3_PCT_REVERSER
   TURB_ENGINE_3_VIBRATION

   TURB_ENGINE_4_N1
   TURB_ENGINE_4_N2
   TURB_ENGINE_4_CORRECTED_N1
   TURB_ENGINE_4_CORRECTED_N2
   TURB_ENGINE_4_CORRECTED_FF
   TURB_ENGINE_4_PCT_MAX_TORQUE
   TURB_ENGINE_4_EPR
   TURB_ENGINE_4_ITT
   TURB_ENGINE_4_AFTERBURNER
   TURB_ENGINE_4_JET_THRUST
   TURB_ENGINE_4_BLEEDAIRPSI
   TURB_ENGINE_4_TANK_SELECTOR
   TURB_ENGINE_4_TANKS_USED
   TURB_ENGINE_4_NUMBER_TANKS
   TURB_ENGINE_4_FUELFLOW_PPH
   TURB_ENGINE_4_FUEL_AVAILABLE
   TURB_ENGINE_4_PCT_AREA
   TURB_ENGINE_4_PCT_REVERSER
   TURB_ENGINE_4_VIBRATION

   PROPELLER_1_RPM                 ' Propeller 1
   PROPELLER_1_PCT_MAX_RPM
   PROPELLER_1_THRUST
   PROPELLER_1_BETA
   PROPELLER_1_FEATHERING_INHIBIT
   PROPELLER_1_FEATHERED
   PROPELLER_1_SYNC_DELTA_LEVER
   PROPELLER_1_AUTOFEATHER_ARMED

   PROPELLER_2_RPM                 ' Propeller 2
   PROPELLER_2_PCT_MAX_RPM
   PROPELLER_2_THRUST
   PROPELLER_2_BETA
   PROPELLER_2_FEATHERING_INHIBIT
   PROPELLER_2_FEATHERED
   PROPELLER_2_SYNC_DELTA_LEVER
   PROPELLER_2_AUTOFEATHER_ARMED

   PROPELLER_3_RPM                 ' Propeller 3
   PROPELLER_3_PCT_MAX_RPM
   PROPELLER_3_THRUST
   PROPELLER_3_BETA
   PROPELLER_3_FEATHERING_INHIBIT
   PROPELLER_3_FEATHERED
   PROPELLER_3_SYNC_DELTA_LEVER
   PROPELLER_3_AUTOFEATHER_ARMED

   PROPELLER_4_RPM                 ' Propeller 4
   PROPELLER_4_PCT_MAX_RPM
   PROPELLER_4_THRUST
   PROPELLER_4_BETA
   PROPELLER_4_FEATHERING_INHIBIT
   PROPELLER_4_FEATHERED
   PROPELLER_4_SYNC_DELTA_LEVER
   PROPELLER_4_AUTOFEATHER_ARMED

   HYDRAULICS1_PRESSURE_PSF
   HYDRAULICS1_RESERVOIR_PCT

   HYDRAULICS2_PRESSURE_PSF
   HYDRAULICS2_RESERVOIR_PCT

   HYDRAULICS3_PRESSURE_PSF
   HYDRAULICS3_RESERVOIR_PCT

   HYDRAULICS4_PRESSURE_PSF
   HYDRAULICS4_RESERVOIR_PCT

   AVIONICS_MASTER_SWITCH

   PANEL_AUTOFEATHER_SWITCH           ' Panel States
   PANEL_ANTIICE_SWITCH
   PANEL_AUTOBRAKE_SWITCH

   DAY_OF_WEEK         ' 0-6
   DAY_OF_MONTH        ' 1-31
   CURRENT_MONTH       ' 1-12
   CURRENT_YEAR        ' 1-????
   TIME_ZONE_OFFSET    ' in minutes, positive west of GMT
   DAYLIGHT_SAVING_ACTIVE ' 0 or 1

   TOTAL_LOAD_AMPS
   BATTERY_LOAD
   BATTERY_VOLTAGE
   MAIN_BUS_VOLTAGE
   MAIN_BUS_AMPS
   AVIONICS_BUS_VOLTAGE
   AVIONICS_BUS_AMPS
   HOT_BATTERY_BUS_VOLTAGE
   HOT_BATTERY_BUS_AMPS
   BATTERY_BUS_VOLTAGE
   BATTERY_BUS_AMPS
   GENERATOR_ALTERNATOR_1_BUS_VOLTAGE
   GENERATOR_ALTERNATOR_1_BUS_AMPS
   GENERATOR_ALTERNATOR_2_BUS_VOLTAGE
   GENERATOR_ALTERNATOR_2_BUS_AMPS
   GENERATOR_ALTERNATOR_3_BUS_VOLTAGE
   GENERATOR_ALTERNATOR_3_BUS_AMPS
   GENERATOR_ALTERNATOR_4_BUS_VOLTAGE
   GENERATOR_ALTERNATOR_4_BUS_AMPS
   GENERAL_PANEL_CIRCUIT_ON
   FLAP_MOTOR_CIRCUIT_ON
   GEAR_MOTOR_CIRCUIT_ON
   AUTOPILOT_CIRCUIT_ON
   AVIONICS_CIRCUIT_ON
   PITOT_HEAT_CIRCUIT_ON
   PROP_SYNC_CIRCUIT_ON
   AUTO_FEATHER_CIRCUIT_ON
   AUTO_BRAKES_CIRCUIT_ON
   STANDBY_VACUUM_CIRCUIT_ON
   MARKER_BEACON_CIRCUIT_ON
   GEAR_WARNING_CIRCUIT_ON
   HYDRAULIC_PUMP_CIRCUIT_ON
   ELEVATOR_DEFLECTION ' radians
   ELEVATOR_TRIM       ' radians
   AILERON_DEFLECTION     ' radians
   AILERON_TRIM        ' radians
   RUDDER_DEFLECTION      ' radians
   RUDDER_TRIM         ' radians

   PROPSYNC_ACTIVE

   INCIDENCE_ALPHA
   INCIDENCE_BETA

   TOTAL_FUEL_QUANTITY_LBS

   FLIGHT_DIRECTOR_ACTIVE
   FLIGHT_DIRECTOR_PITCH     ' degrees
   FLIGHT_DIRECTOR_BANK      ' degrees

   CG_PERCENT
   CG_AFT_LIMIT
   CG_FWD_LIMIT
   CG_MAX_MACH
   CG_MIN_MACH

   STANDARD_ATM_TEMPERATURE  ' standard atmosphere temperature at aircraft's altitude; celsius

   ENGINE_1_FUELFLOW_BUG_POSITION     ' lbs per hour
   ENGINE_2_FUELFLOW_BUG_POSITION
   ENGINE_3_FUELFLOW_BUG_POSITION
   ENGINE_4_FUELFLOW_BUG_POSITION

   CONCORDE_VISOR_NOSE_HANDLE   ' 0 - Visor Up, Nose Up, 1 - Visor Dn, Nose Up, 2 - Visor Dn, Nose 5 deg, 3 - Visor Dn, Nose 12.5 deg
   CONCORDE_VISOR_POS_PCT    ' 0=Up, 1.0 Extended/Down
   CONCORDE_NOSE_ANGLE    ' degrees; 0 - up

   GEAR_POS_TAIL

   ELEVON_1_DEFLECTION    ' The elevon indices start at 1 at the far left and increase to the right.
   ELEVON_2_DEFLECTION    ' radians
   ELEVON_3_DEFLECTION
   ELEVON_4_DEFLECTION
   ELEVON_5_DEFLECTION
   ELEVON_6_DEFLECTION
   ELEVON_7_DEFLECTION
   ELEVON_8_DEFLECTION

   PANEL_AUTOPILOT_SPEED_SETTING      ' Knots
   AUTOPILOT_AIRSPEED_ACQUISITION     ' boolean
   AUTOPILOT_AIRSPEED_HOLD_CURRENT ' boolean
   AUTOPILOT_MAX_SPEED          ' boolean
   AUTOPILOT_CRUISE_SPEED          ' boolean

   BARBER_POLE_MACH             ' real mach

   SELECTED_FUEL_TRANSFER_MODE     ' -1 off, 0 auto, 1 forward, 2 aft

   HYDRAULIC_SYSTEM_INTEGRITY         ' 0.0 - complete failure; 1.0 - everything is ok

   ATTITUDE_CAGE_BUTTON

   VOR1_NEEDLE_RADIO               ' +-127 correspond to +-10 if VOR or to +-2.5 if localiser. Driven always by VOR
   GPS_POSITION_LAT
   GPS_POSITION_LON
   GPS_POSITION_ALT
   GPS_MAGVAR                   ' magnetic deviation (radians)
   GPS_FLAGS                    ' GPS_FLAG_ACTIVE_FLIGHT_PLAN = 0x00002  there is an active flight plan
                              ' GPS_FLAG_ACTIVE_WAY_POINT   = 0x00004  there is an active way point
                              ' GPS_FLAG_ARRIVED            = 0x00008  last waypoint reached
                              ' GPS_FLAG_DIRECTTO_FLIGHTPLAN= 0x00020  manual flight plan
   GPS_GROUND_SPEED             ' meters per second
   GPS_GROUND_HEADING              ' radians (0 - 2PI); true heading, yaw
   GPS_GROUND_TRACK             ' radians (0 - 2PI); heading + magvar, magnetic yaw
    GPS_WP_DISTANCE             ' meters to next wp
    GPS_WP_BEARING                 ' heading (radians) to next wp + magvar
    GPS_WP_CROSS_TRK               ' cross_trk (meters)
    GPS_WP_REQ_HDG                 ' required heading, magnetic, radians (0 - 2PI), from prev wp to next wp
    GPS_WP_STRING                  ' name of next waypoint
   GPS_WP_NEXT_LAT
   GPS_WP_NEXT_LON
   GPS_WP_NEXT_ALT
   GPS_WP_PREV_LAT
   GPS_WP_PREV_LON
   GPS_WP_PREV_ALT
   GPS_WP_TRUE_BEARING          ' true bearing, degrees
   GPS_WP_TRUE_REQ_HDG          ' true required heading, degrees

   GPS_DRIVES_NAV1

   HSI_VERTICAL_NEEDLE          ' -1.0 .. 1.0 corresponds to -10deg .. 10deg if VOR or to -2.5deg .. +2.5deg if localiser +5NM .. -5NM  if GPS
   HSI_HORIZONTAL_NEEDLE           ' -1.0 .. 1.0 corresponds to -0.7deg .. +0.7deg
   HSI_VERTICAL_VALID              ' 0 - Nav flag on
   HSI_HORIZONTAL_VALID            ' 0 - GS flag on
   HSI_TF_FLAG                  ' -1.0 - from. 0.0 - none, 1.0 - to
   HSI_OBI_NEEDLE                  ' 0 .. 360
   HSI_DESIRED_HEADING_NEEDLE         ' 0 .. 360
   HSI_BEARING                  ' 0 .. 360
   HSI_BEARING_VALID               ' 1 - true
   HSI_SIGNAL_LOCALISER            ' 1 - true
   HSI_SPEED                    ' knots
   HSI_DISTANCE                 ' NM
   HSI_STATION_NAME             ' string

   GEAR_POS_AUX                 '      Aux gear  0 - 16k
   TOOLTIP_UNITS                ' enum TOOLTIP_UNITS_TYPE
   LSO_TEXTURE_ID                  ' current LSO_Texture_Id in AI_PLAYER.mw
   LSO_TEXT                     ' text
   LEFT_FOLDING_WING_PERCENT       ' 0 - not folded; 1 - folded
   RIGHT_FOLDING_WING_PERCENT         ' 0 - not folded; 1 - folded
   MAIN_EXIT_OPEN                  ' 0 - not open; 1 - open
   TAILHOOK_POSITION                  ' 0 - retracted; 1 - extended

   COM2_FREQUENCY                  ' BCD same as COM_FREQUENCY
   COM2_STBY_FREQUENCY           ' BCD; same as COM_FREQUENCY
   NAV1_STBY_FREQUENCY           ' BCD NAV1 radio freq; same as NAV1_FREQUENCY
   NAV2_STBY_FREQUENCY           ' BCD NAV2 radio freq; same as NAV2_FREQUENCY
   COM1_TRANSMIT_SELECT            ' 1.0 - yes
   COM2_TRANSMIT_SELECT            ' 1.0 - yes
   COM_BOTH_RECEIVE             ' 1.0 - yes
   NAV1_SOUND_TOGGLE
   NAV2_SOUND_TOGGLE
   DME_SOUND_TOGGLE
   ADF_SOUND_TOGGLE
   MARKER_SOUND_TOGGLE
   VOR2_GS_NEEDLE

   GENERAL_ENGINE1_ANTI_ICE_POS     '0 - off 1 - on
   GENERAL_ENGINE2_ANTI_ICE_POS     '0 - off 1 - on
   GENERAL_ENGINE3_ANTI_ICE_POS     '0 - off 1 - on
   GENERAL_ENGINE4_ANTI_ICE_POS     '0 - off 1 - on
   ENGINE1_ON_FIRE              ' 0 - no, 1 - yes
   ENGINE2_ON_FIRE
   ENGINE3_ON_FIRE
   ENGINE4_ON_FIRE
   ENGINE1_FUEL_PUMP_ON            ' 0 - no, 1 - yes
   ENGINE2_FUEL_PUMP_ON            ' 0 - no, 1 - yes
   ENGINE3_FUEL_PUMP_ON            ' 0 - no, 1 - yes
   ENGINE4_FUEL_PUMP_ON            ' 0 - no, 1 - yes
   
   GENERAL_ENGINE1_FUEL_VALVE         '1 = Open, 0 = Closed
   GENERAL_ENGINE2_FUEL_VALVE         '1 = Open, 0 = Closed
   GENERAL_ENGINE3_FUEL_VALVE         '1 = Open, 0 = Closed
   GENERAL_ENGINE4_FUEL_VALVE         '1 = Open, 0 = Closed
   
   GENERAL_ENGINE1_FUEL_PRESSURE
   GENERAL_ENGINE2_FUEL_PRESSURE
   GENERAL_ENGINE3_FUEL_PRESSURE
   GENERAL_ENGINE4_FUEL_PRESSURE


   WATER_RUDDER_ON              ' 0 - up, 1 - down
   PROP_DEICE_SWITCH               ' 0 = off, 1 = on
   STRUCTURAL_DEICE_SWITCH         ' 0 = off, 1 = on
   FUEL_TANK_SELECTOR_2            '  see FUEL_TANK_SELECTOR_ enum values
   TRAILING_EDGE_FLAPS0_LEFT_ANGLE ' Angle of primary trailing edge flaps
   TRAILING_EDGE_FLAPS0_RIGHT_ANGLE   ' Angle of primary trailing edge flaps

   C_GAUGE_TOKEN                 ' Always the last

End Enum


'
' Key Accelerator Event IDs
'

Public Const KEY_ID_MIN = &H10000

Public Const KEY_NULL = (KEY_ID_MIN + 0)
Public Const KEY_DEMO_STOP = (KEY_ID_MIN + 1)
Public Const KEY_REPLAY_STOP = (KEY_ID_MIN + 1)
Public Const KEY_SELECT_1 = (KEY_ID_MIN + 2)
Public Const KEY_SELECT_2 = (KEY_ID_MIN + 3)
Public Const KEY_SELECT_3 = (KEY_ID_MIN + 4)
Public Const KEY_SELECT_4 = (KEY_ID_MIN + 5)
Public Const KEY_DEMO_RECORD_1_SEC = (KEY_ID_MIN + 7)
Public Const KEY_DEMO_RECORD_5_SEC = (KEY_ID_MIN + 8)
Public Const KEY_MINUS = (KEY_ID_MIN + 12)
Public Const KEY_PLUS = (KEY_ID_MIN + 13)
Public Const KEY_ZOOM_1X = (KEY_ID_MIN + 14)
Public Const KEY_PANEL_SELECT_1 = (KEY_ID_MIN + 15)
Public Const KEY_SOUND_TOGGLE = (KEY_ID_MIN + 16)
Public Const KEY_FULL_WINDOW_TOGGLE = (KEY_ID_MIN + 17)
Public Const KEY_ENGINE = (KEY_ID_MIN + 18)
Public Const KEY_SIM_RATE = (KEY_ID_MIN + 19)
Public Const KEY_XPNDR = (KEY_ID_MIN + 20)
Public Const KEY_SLEW_TOGGLE = (KEY_ID_MIN + 21)
Public Const KEY_EGT = (KEY_ID_MIN + 22)
Public Const KEY_SMOKE_TOGGLE = (KEY_ID_MIN + 23)
Public Const KEY_STROBES_TOGGLE = (KEY_ID_MIN + 24)
Public Const KEY_PAUSE_TOGGLE = (KEY_ID_MIN + 25)
Public Const KEY_REFRESH_SCENERY = (KEY_ID_MIN + 26)
Public Const KEY_ATC = (KEY_ID_MIN + 28)
Public Const KEY_ADF = (KEY_ID_MIN + 30)
Public Const KEY_VIEW_MODE = (KEY_ID_MIN + 31)
Public Const KEY_HEADING_GYRO_SET = (KEY_ID_MIN + 32)
Public Const KEY_DME = (KEY_ID_MIN + 33)
Public Const KEY_GEAR_TOGGLE = (KEY_ID_MIN + 34)
Public Const KEY_ANTI_ICE_TOGGLE = (KEY_ID_MIN + 35)
Public Const KEY_JET_STARTER = (KEY_ID_MIN + 36)
Public Const KEY_JOYSTICK_CALIBRATE = (KEY_ID_MIN + 37)
Public Const KEY_ALL_LIGHTS_TOGGLE = (KEY_ID_MIN + 38)
Public Const KEY_SITUATION_SAVE = (KEY_ID_MIN + 39)
Public Const KEY_VIEW_WINDOW_TO_FRONT = (KEY_ID_MIN + 40)
Public Const KEY_DEMO_RECORD_STOP = (KEY_ID_MIN + 43)
Public Const KEY_ANALYSIS_MANEUVER_STOP = (KEY_ID_MIN + 43)
Public Const KEY_AP_MASTER = (KEY_ID_MIN + 44)
Public Const KEY_FREQUENCY_SWAP = (KEY_ID_MIN + 45)
Public Const KEY_COM_RADIO = (KEY_ID_MIN + 46)
Public Const KEY_VOR_OBS = (KEY_ID_MIN + 47)
Public Const KEY_BAROMETRIC = (KEY_ID_MIN + 48)
Public Const KEY_NAV_RADIO = (KEY_ID_MIN + 49)
Public Const KEY_MAGNETO = (KEY_ID_MIN + 50)
Public Const KEY_DEMO_RECORD_MESSAGE = (KEY_ID_MIN + 51)
Public Const KEY_BRAKES = (KEY_ID_MIN + 52)
Public Const KEY_SPOILERS_TOGGLE = (KEY_ID_MIN + 53)
Public Const KEY_SITUATION_RESET = (KEY_ID_MIN + 55)
Public Const KEY_FLAPS_UP = (KEY_ID_MIN + 59)
Public Const KEY_THROTTLE_FULL = (KEY_ID_MIN + 60)
Public Const KEY_FLAPS_1 = (KEY_ID_MIN + 61)
Public Const KEY_THROTTLE_INCR = (KEY_ID_MIN + 62)
Public Const KEY_FLAPS_2 = (KEY_ID_MIN + 63)
Public Const KEY_THROTTLE_INCR_SMALL = (KEY_ID_MIN + 64)
Public Const KEY_FLAPS_3 = (KEY_ID_MIN + 65)
Public Const KEY_THROTTLE_DECR = (KEY_ID_MIN + 66)
Public Const KEY_FLAPS_4 = (KEY_ID_MIN + 67)
Public Const KEY_FLAPS_DOWN = (KEY_ID_MIN + 67)
Public Const KEY_THROTTLE_CUT = (KEY_ID_MIN + 68)
Public Const KEY_VIEW = (KEY_ID_MIN + 70)
Public Const KEY_ELEV_TRIM_DN = (KEY_ID_MIN + 71)
Public Const KEY_ELEV_DOWN = (KEY_ID_MIN + 72)
Public Const KEY_INCREASE_THROTTLE = (KEY_ID_MIN + 73)
Public Const KEY_AILERONS_LEFT = (KEY_ID_MIN + 75)
Public Const KEY_CENTER_AILER_RUDDER = (KEY_ID_MIN + 76)
Public Const KEY_AILERONS_RIGHT = (KEY_ID_MIN + 77)
Public Const KEY_ELEV_TRIM_UP = (KEY_ID_MIN + 79)
Public Const KEY_ELEV_UP = (KEY_ID_MIN + 80)
Public Const KEY_DECREASE_THROTTLE = (KEY_ID_MIN + 81)
Public Const KEY_MOUSE_AS_YOKE_TOGGLE = (KEY_ID_MIN + 83)
Public Const KEY_SLEW_ALTIT_UP_FAST = (KEY_ID_MIN + 84)
Public Const KEY_SLEW_ALTIT_UP_SLOW = (KEY_ID_MIN + 85)
Public Const KEY_SLEW_ALTIT_FREEZE = (KEY_ID_MIN + 86)
Public Const KEY_SLEW_ALTIT_DN_SLOW = (KEY_ID_MIN + 87)
Public Const KEY_SLEW_ALTIT_DN_FAST = (KEY_ID_MIN + 88)
Public Const KEY_SLEW_ALTIT_PLUS = (KEY_ID_MIN + 89)
Public Const KEY_SLEW_ALTIT_MINUS = (KEY_ID_MIN + 90)
Public Const KEY_SLEW_PITCH_DN_FAST = (KEY_ID_MIN + 91)
Public Const KEY_SLEW_PITCH_DN_SLOW = (KEY_ID_MIN + 92)
Public Const KEY_SLEW_PITCH_FREEZE = (KEY_ID_MIN + 93)
Public Const KEY_SLEW_PITCH_UP_SLOW = (KEY_ID_MIN + 94)
Public Const KEY_SLEW_PITCH_UP_FAST = (KEY_ID_MIN + 95)
Public Const KEY_SLEW_PITCH_PLUS = (KEY_ID_MIN + 96)
Public Const KEY_SLEW_PITCH_MINUS = (KEY_ID_MIN + 97)
Public Const KEY_MAGNETO_DECR = (KEY_ID_MIN + 98)
Public Const KEY_MAGNETO_INCR = (KEY_ID_MIN + 99)
Public Const KEY_COM_RADIO_WHOLE_DEC = (KEY_ID_MIN + 100)
Public Const KEY_COM_RADIO_WHOLE_INC = (KEY_ID_MIN + 101)
Public Const KEY_COM_RADIO_FRACT_DEC = (KEY_ID_MIN + 102)
Public Const KEY_COM_RADIO_FRACT_INC = (KEY_ID_MIN + 103)
Public Const KEY_NAV1_RADIO_WHOLE_DEC = (KEY_ID_MIN + 104)
Public Const KEY_NAV1_RADIO_WHOLE_INC = (KEY_ID_MIN + 105)
Public Const KEY_NAV1_RADIO_FRACT_DEC = (KEY_ID_MIN + 106)
Public Const KEY_NAV1_RADIO_FRACT_INC = (KEY_ID_MIN + 107)
Public Const KEY_NAV2_RADIO_WHOLE_DEC = (KEY_ID_MIN + 108)
Public Const KEY_NAV2_RADIO_WHOLE_INC = (KEY_ID_MIN + 109)
Public Const KEY_NAV2_RADIO_FRACT_DEC = (KEY_ID_MIN + 110)
Public Const KEY_NAV2_RADIO_FRACT_INC = (KEY_ID_MIN + 111)
Public Const KEY_ADF_100_INC = (KEY_ID_MIN + 112)
Public Const KEY_ADF_10_INC = (KEY_ID_MIN + 113)
Public Const KEY_ADF_1_INC = (KEY_ID_MIN + 114)
Public Const KEY_XPNDR_1000_INC = (KEY_ID_MIN + 115)
Public Const KEY_XPNDR_100_INC = (KEY_ID_MIN + 116)
Public Const KEY_XPNDR_10_INC = (KEY_ID_MIN + 117)
Public Const KEY_XPNDR_1_INC = (KEY_ID_MIN + 118)
Public Const KEY_ZOOM_IN = (KEY_ID_MIN + 119)
Public Const KEY_ZOOM_OUT = (KEY_ID_MIN + 120)
Public Const KEY_CLOCK_HOURS_DEC = (KEY_ID_MIN + 121)
Public Const KEY_CLOCK_HOURS_INC = (KEY_ID_MIN + 122)
Public Const KEY_CLOCK_MINUTES_DEC = (KEY_ID_MIN + 123)
Public Const KEY_CLOCK_MINUTES_INC = (KEY_ID_MIN + 124)
Public Const KEY_CLOCK_SECONDS_ZERO = (KEY_ID_MIN + 125)
Public Const KEY_VOR1_OBI_DEC = (KEY_ID_MIN + 126)
Public Const KEY_VOR1_OBI_INC = (KEY_ID_MIN + 127)
Public Const KEY_VOR2_OBI_DEC = (KEY_ID_MIN + 128)
Public Const KEY_VOR2_OBI_INC = (KEY_ID_MIN + 129)
Public Const KEY_ADF_100_DEC = (KEY_ID_MIN + 130)
Public Const KEY_ADF_10_DEC = (KEY_ID_MIN + 131)
Public Const KEY_ADF_1_DEC = (KEY_ID_MIN + 132)
Public Const KEY_AP_MASTER_ALT = (KEY_ID_MIN + 133)
Public Const KEY_MAP_ZOOM_FINE_IN = (KEY_ID_MIN + 134)
Public Const KEY_PAN_LEFT = (KEY_ID_MIN + 135)
Public Const KEY_PAN_RIGHT = (KEY_ID_MIN + 136)
Public Const KEY_MAP_ZOOM_FINE_OUT = (KEY_ID_MIN + 137)
Public Const KEY_VIEW_FORWARD = (KEY_ID_MIN + 138)
Public Const KEY_VIEW_FORWARD_RIGHT = (KEY_ID_MIN + 139)
Public Const KEY_VIEW_RIGHT = (KEY_ID_MIN + 140)
Public Const KEY_VIEW_REAR_RIGHT = (KEY_ID_MIN + 141)
Public Const KEY_VIEW_REAR = (KEY_ID_MIN + 142)
Public Const KEY_VIEW_REAR_LEFT = (KEY_ID_MIN + 143)
Public Const KEY_VIEW_LEFT = (KEY_ID_MIN + 144)
Public Const KEY_VIEW_FORWARD_LEFT = (KEY_ID_MIN + 145)
Public Const KEY_VIEW_DOWN = (KEY_ID_MIN + 146)
Public Const KEY_ELEVATOR_DOWN = (KEY_ID_MIN + 147)
Public Const KEY_ELEVATOR_UP = (KEY_ID_MIN + 148)
Public Const KEY_AILERON_LEFT = (KEY_ID_MIN + 149)
Public Const KEY_AILERON_CENTER = (KEY_ID_MIN + 150)
Public Const KEY_AILERON_RIGHT = (KEY_ID_MIN + 151)
Public Const KEY_RUDDER_LEFT = (KEY_ID_MIN + 152)
Public Const KEY_RUDDER_CENTER = (KEY_ID_MIN + 153)
Public Const KEY_RUDDER_RIGHT = (KEY_ID_MIN + 154)
Public Const KEY_VIEW1_MODE_SET = (KEY_ID_MIN + 155)
Public Const KEY_SOUND_SET = (KEY_ID_MIN + 156)
Public Const KEY_VIEW1_DIRECTION_SET = (KEY_ID_MIN + 157)
Public Const KEY_ELEVATOR_SET = (KEY_ID_MIN + 158)
Public Const KEY_AILERON_SET = (KEY_ID_MIN + 159)
Public Const KEY_RUDDER_SET = (KEY_ID_MIN + 160)
Public Const KEY_THROTTLE_SET = (KEY_ID_MIN + 161)
Public Const KEY_FLAPS_SET = (KEY_ID_MIN + 162)
Public Const KEY_GEAR_SET = (KEY_ID_MIN + 164)
Public Const KEY_VIEW1_ZOOM_SET = (KEY_ID_MIN + 165)
Public Const KEY_AXIS_IND_SET = (KEY_ID_MIN + 166)
Public Const KEY_ELEVATOR_TRIM_SET = (KEY_ID_MIN + 170)
Public Const KEY_COM_RADIO_SET = (KEY_ID_MIN + 171)
Public Const KEY_NAV1_RADIO_SET = (KEY_ID_MIN + 172)
Public Const KEY_NAV2_RADIO_SET = (KEY_ID_MIN + 173)
Public Const KEY_VIEW2_MODE_SET = (KEY_ID_MIN + 174)
Public Const KEY_VIEW2_DIRECTION_SET = (KEY_ID_MIN + 175)
Public Const KEY_VIEW2_ZOOM_SET = (KEY_ID_MIN + 176)
Public Const KEY_MAP_ZOOM_SET = (KEY_ID_MIN + 177)
Public Const KEY_ADF_SET = (KEY_ID_MIN + 178)
Public Const KEY_XPNDR_SET = (KEY_ID_MIN + 179)
Public Const KEY_VOR1_SET = (KEY_ID_MIN + 180)
Public Const KEY_VOR2_SET = (KEY_ID_MIN + 181)
Public Const KEY_ZOOM_MINUS = (KEY_ID_MIN + 182)
Public Const KEY_ZOOM_PLUS = (KEY_ID_MIN + 183)
Public Const KEY_BRAKES_LEFT = (KEY_ID_MIN + 184)
Public Const KEY_BRAKES_RIGHT = (KEY_ID_MIN + 185)
Public Const KEY_AP_ATT_HOLD = (KEY_ID_MIN + 186)
Public Const KEY_AP_LOC_HOLD = (KEY_ID_MIN + 187)
Public Const KEY_AP_APR_HOLD = (KEY_ID_MIN + 188)
Public Const KEY_AP_HDG_HOLD = (KEY_ID_MIN + 189)
Public Const KEY_AP_ALT_HOLD = (KEY_ID_MIN + 190)
Public Const KEY_AP_WING_LEVELER = (KEY_ID_MIN + 191)
Public Const KEY_AP_BC_HOLD = (KEY_ID_MIN + 192)
Public Const KEY_AP_NAV1_HOLD = (KEY_ID_MIN + 193)
Public Const KEY_SLEW_OFF = (KEY_ID_MIN + 194)
Public Const KEY_SLEW_ON = (KEY_ID_MIN + 195)
Public Const KEY_EXIT = (KEY_ID_MIN + 196)
Public Const KEY_ABORT = (KEY_ID_MIN + 197)
Public Const KEY_PAN_UP = (KEY_ID_MIN + 198)
Public Const KEY_PAN_DOWN = (KEY_ID_MIN + 199)
Public Const KEY_READOUTS_SLEW = (KEY_ID_MIN + 200)
Public Const KEY_READOUTS_FLIGHT = (KEY_ID_MIN + 201)
Public Const KEY_SLEW_BANK_MINUS = (KEY_ID_MIN + 202)
Public Const KEY_SLEW_AHEAD_PLUS = (KEY_ID_MIN + 203)
Public Const KEY_SLEW_BANK_PLUS = (KEY_ID_MIN + 204)
Public Const KEY_SLEW_LEFT = (KEY_ID_MIN + 205)
Public Const KEY_SLEW_FREEZE = (KEY_ID_MIN + 206)
Public Const KEY_SLEW_RIGHT = (KEY_ID_MIN + 207)
Public Const KEY_SLEW_HEADING_MINUS = (KEY_ID_MIN + 208)
Public Const KEY_SLEW_AHEAD_MINUS = (KEY_ID_MIN + 209)
Public Const KEY_SLEW_HEADING_PLUS = (KEY_ID_MIN + 210)
Public Const KEY_PANEL_SELECT_2 = (KEY_ID_MIN + 211)
Public Const KEY_PANEL_TOGGLE = (KEY_ID_MIN + 212)
Public Const KEY_VIEW_MODE_REV = (KEY_ID_MIN + 213)
Public Const KEY_PANEL_LIGHTS_TOGGLE = (KEY_ID_MIN + 214)
Public Const KEY_LANDING_LIGHTS_TOGGLE = (KEY_ID_MIN + 215)
Public Const KEY_PARKING_BRAKES = (KEY_ID_MIN + 216)
Public Const KEY_ZOOM_IN_FINE = (KEY_ID_MIN + 218)
Public Const KEY_ZOOM_OUT_FINE = (KEY_ID_MIN + 219)
Public Const KEY_MINUS_SHIFT = (KEY_ID_MIN + 220)
Public Const KEY_PLUS_SHIFT = (KEY_ID_MIN + 221)
Public Const KEY_FLAPS_INCR = (KEY_ID_MIN + 222)
Public Const KEY_FLAPS_DECR = (KEY_ID_MIN + 223)
Public Const KEY_FLAPS_DETENTS_SET = (KEY_ID_MIN + 224)
Public Const KEY_AXIS_ELEVATOR_SET = (KEY_ID_MIN + 226)
Public Const KEY_AXIS_AILERONS_SET = (KEY_ID_MIN + 227)
Public Const KEY_AXIS_RUDDER_SET = (KEY_ID_MIN + 228)
Public Const KEY_AXIS_THROTTLE_SET = (KEY_ID_MIN + 229)
Public Const KEY_AXIS_ELEV_TRIM_SET = (KEY_ID_MIN + 230)
Public Const KEY_PROP_PITCH_SET = (KEY_ID_MIN + 231)
Public Const KEY_PROP_PITCH_LO = (KEY_ID_MIN + 232)
Public Const KEY_PROP_PITCH_INCR = (KEY_ID_MIN + 233)
Public Const KEY_PROP_PITCH_INCR_SMALL = (KEY_ID_MIN + 234)
Public Const KEY_PROP_PITCH_DECR = (KEY_ID_MIN + 235)
Public Const KEY_PROP_PITCH_HI = (KEY_ID_MIN + 236)
Public Const KEY_MIXTURE_SET = (KEY_ID_MIN + 237)
Public Const KEY_MIXTURE_RICH = (KEY_ID_MIN + 238)
Public Const KEY_MIXTURE_INCR = (KEY_ID_MIN + 239)
Public Const KEY_MIXTURE_INCR_SMALL = (KEY_ID_MIN + 240)
Public Const KEY_MIXTURE_DECR = (KEY_ID_MIN + 241)
Public Const KEY_MIXTURE_LEAN = (KEY_ID_MIN + 242)
Public Const KEY_SCRIPT_EVENT_1 = (KEY_ID_MIN + 246)
Public Const KEY_SCRIPT_EVENT_2 = (KEY_ID_MIN + 247)
Public Const KEY_SPOILERS_SET = (KEY_ID_MIN + 250)
Public Const KEY_DME1_TOGGLE = (KEY_ID_MIN + 251)
Public Const KEY_DME2_TOGGLE = (KEY_ID_MIN + 252)
Public Const KEY_SIM_RATE_INCR = (KEY_ID_MIN + 253)
Public Const KEY_SIM_RATE_DECR = (KEY_ID_MIN + 254)
Public Const KEY_AUTOPILOT_OFF = (KEY_ID_MIN + 255)
Public Const KEY_AUTOPILOT_ON = (KEY_ID_MIN + 256)
Public Const KEY_YAW_DAMPER_TOGGLE = (KEY_ID_MIN + 257)
Public Const KEY_PAUSE_ON = (KEY_ID_MIN + 258)
Public Const KEY_PAUSE_OFF = (KEY_ID_MIN + 259)
Public Const KEY_SLEW_RESET = (KEY_ID_MIN + 260)
Public Const KEY_AP_PANEL_HEADING_HOLD = (KEY_ID_MIN + 262)
Public Const KEY_AP_PANEL_ALTITUDE_HOLD = (KEY_ID_MIN + 263)
Public Const KEY_CHVPP_LEFT_HAT_UP = (KEY_ID_MIN + 264)
Public Const KEY_CHVPP_LEFT_HAT_DOWN = (KEY_ID_MIN + 265)
Public Const KEY_CHVPP_AP_ALT_WING = (KEY_ID_MIN + 266)
Public Const KEY_CENTER_NT361_CHECK = (KEY_ID_MIN + 267)
Public Const KEY_AP_ATT_HOLD_ON = (KEY_ID_MIN + 268)
Public Const KEY_AP_LOC_HOLD_ON = (KEY_ID_MIN + 269)
Public Const KEY_AP_APR_HOLD_ON = (KEY_ID_MIN + 270)
Public Const KEY_AP_HDG_HOLD_ON = (KEY_ID_MIN + 271)
Public Const KEY_AP_ALT_HOLD_ON = (KEY_ID_MIN + 272)
Public Const KEY_AP_WING_LEVELER_ON = (KEY_ID_MIN + 273)
Public Const KEY_AP_BC_HOLD_ON = (KEY_ID_MIN + 274)
Public Const KEY_AP_NAV1_HOLD_ON = (KEY_ID_MIN + 275)
Public Const KEY_AP_ATT_HOLD_OFF = (KEY_ID_MIN + 276)
Public Const KEY_AP_LOC_HOLD_OFF = (KEY_ID_MIN + 277)
Public Const KEY_AP_APR_HOLD_OFF = (KEY_ID_MIN + 278)
Public Const KEY_AP_HDG_HOLD_OFF = (KEY_ID_MIN + 279)
Public Const KEY_AP_ALT_HOLD_OFF = (KEY_ID_MIN + 280)
Public Const KEY_AP_WING_LEVELER_OFF = (KEY_ID_MIN + 281)
Public Const KEY_AP_BC_HOLD_OFF = (KEY_ID_MIN + 282)
Public Const KEY_AP_NAV1_HOLD_OFF = (KEY_ID_MIN + 283)
Public Const KEY_THROTTLE1_SET = (KEY_ID_MIN + 284)
Public Const KEY_THROTTLE2_SET = (KEY_ID_MIN + 285)
Public Const KEY_THROTTLE3_SET = (KEY_ID_MIN + 286)
Public Const KEY_THROTTLE4_SET = (KEY_ID_MIN + 287)
Public Const KEY_CLOSE_VIEW = (KEY_ID_MIN + 288)
Public Const KEY_NEW_VIEW = (KEY_ID_MIN + 289)
Public Const KEY_NEW_MAP = (KEY_ID_MIN + 290)
Public Const KEY_NEXT_VIEW = (KEY_ID_MIN + 291)
Public Const KEY_PREV_VIEW = (KEY_ID_MIN + 292)
Public Const KEY_VIEW_TYPE = (KEY_ID_MIN + 293)
Public Const KEY_VIEW_TYPE_REV = (KEY_ID_MIN + 294)
Public Const KEY_VIEW_TYPE_SET = (KEY_ID_MIN + 295)
Public Const KEY_RADIO_VOR1_IDENT_DISABLE = (KEY_ID_MIN + 296)
Public Const KEY_RADIO_VOR2_IDENT_DISABLE = (KEY_ID_MIN + 297)
Public Const KEY_RADIO_DME1_IDENT_DISABLE = (KEY_ID_MIN + 298)
Public Const KEY_RADIO_DME2_IDENT_DISABLE = (KEY_ID_MIN + 299)
Public Const KEY_RADIO_ADF_IDENT_DISABLE = (KEY_ID_MIN + 300)
Public Const KEY_RADIO_VOR1_IDENT_ENABLE = (KEY_ID_MIN + 301)
Public Const KEY_RADIO_VOR2_IDENT_ENABLE = (KEY_ID_MIN + 302)
Public Const KEY_RADIO_DME1_IDENT_ENABLE = (KEY_ID_MIN + 303)
Public Const KEY_RADIO_DME2_IDENT_ENABLE = (KEY_ID_MIN + 304)
Public Const KEY_RADIO_ADF_IDENT_ENABLE = (KEY_ID_MIN + 305)
Public Const KEY_RADIO_VOR1_IDENT_TOGGLE = (KEY_ID_MIN + 306)
Public Const KEY_RADIO_VOR2_IDENT_TOGGLE = (KEY_ID_MIN + 307)
Public Const KEY_RADIO_DME1_IDENT_TOGGLE = (KEY_ID_MIN + 308)
Public Const KEY_RADIO_DME2_IDENT_TOGGLE = (KEY_ID_MIN + 309)
Public Const KEY_RADIO_ADF_IDENT_TOGGLE = (KEY_ID_MIN + 310)
Public Const KEY_RADIO_VOR1_IDENT_SET = (KEY_ID_MIN + 311)
Public Const KEY_RADIO_VOR2_IDENT_SET = (KEY_ID_MIN + 312)
Public Const KEY_RADIO_DME1_IDENT_SET = (KEY_ID_MIN + 313)
Public Const KEY_RADIO_DME2_IDENT_SET = (KEY_ID_MIN + 314)
Public Const KEY_RADIO_ADF_IDENT_SET = (KEY_ID_MIN + 315)
Public Const KEY_GEAR_PUMP = (KEY_ID_MIN + 316)
Public Const KEY_SPOILERS_ARM_TOGGLE = (KEY_ID_MIN + 317)
Public Const KEY_PAN_LEFT_UP = (KEY_ID_MIN + 318)
Public Const KEY_PAN_LEFT_DOWN = (KEY_ID_MIN + 319)
Public Const KEY_PAN_RIGHT_UP = (KEY_ID_MIN + 320)
Public Const KEY_PAN_RIGHT_DOWN = (KEY_ID_MIN + 321)
Public Const KEY_PITOT_HEAT_TOGGLE = (KEY_ID_MIN + 322)
Public Const KEY_AP_AIRSPEED_HOLD = (KEY_ID_MIN + 323)
Public Const KEY_AUTO_THROTTLE_ARM = (KEY_ID_MIN + 324)
Public Const KEY_AUTO_THROTTLE_TO_GA = (KEY_ID_MIN + 325)
Public Const KEY_LANDING_LIGHT_UP = (KEY_ID_MIN + 326)
Public Const KEY_LANDING_LIGHT_DOWN = (KEY_ID_MIN + 327)
Public Const KEY_LANDING_LIGHT_LEFT = (KEY_ID_MIN + 328)
Public Const KEY_LANDING_LIGHT_RIGHT = (KEY_ID_MIN + 329)
Public Const KEY_LANDING_LIGHT_HOME = (KEY_ID_MIN + 330)
Public Const KEY_AXIS_SLEW_AHEAD_SET = (KEY_ID_MIN + 331)
Public Const KEY_AXIS_SLEW_SIDEWAYS_SET = (KEY_ID_MIN + 332)
Public Const KEY_AXIS_SLEW_HEADING_SET = (KEY_ID_MIN + 333)
Public Const KEY_AXIS_SLEW_ALT_SET = (KEY_ID_MIN + 334)
Public Const KEY_AXIS_SLEW_BANK_SET = (KEY_ID_MIN + 335)
Public Const KEY_AXIS_SLEW_PITCH_SET = (KEY_ID_MIN + 336)
Public Const KEY_PAN_TILT_LEFT = (KEY_ID_MIN + 337)
Public Const KEY_PAN_TILT_RIGHT = (KEY_ID_MIN + 338)
Public Const KEY_PAN_RESET = (KEY_ID_MIN + 339)
Public Const KEY_KNEEBOARD = (KEY_ID_MIN + 340)
Public Const KEY_GYRO_DRIFT_INC = (KEY_ID_MIN + 341)
Public Const KEY_GYRO_DRIFT_DEC = (KEY_ID_MIN + 342)
Public Const KEY_HEADING_BUG_INC = (KEY_ID_MIN + 343)
Public Const KEY_HEADING_BUG_DEC = (KEY_ID_MIN + 344)
Public Const KEY_ADF_CARD_INC = (KEY_ID_MIN + 345)
Public Const KEY_ADF_CARD_DEC = (KEY_ID_MIN + 346)
Public Const KEY_KOHLSMAN_INC = (KEY_ID_MIN + 347)
Public Const KEY_KOHLSMAN_DEC = (KEY_ID_MIN + 348)
Public Const KEY_TRUE_AIRSPEED_CALIBRATE_INC = (KEY_ID_MIN + 349)
Public Const KEY_TRUE_AIRSPEED_CALIBRATE_DEC = (KEY_ID_MIN + 350)
Public Const KEY_CROSS_FEED_OFF = (KEY_ID_MIN + 351)
Public Const KEY_CROSS_FEED_LEFT_TO_RIGHT = (KEY_ID_MIN + 352)
Public Const KEY_CROSS_FEED_RIGHT_TO_LEFT = (KEY_ID_MIN + 353)
Public Const KEY_AP_PANEL_VS_HOLD = (KEY_ID_MIN + 354)
Public Const KEY_AP_PANEL_SPEED_HOLD = (KEY_ID_MIN + 355)
Public Const KEY_AP_ALT_VAR_INC = (KEY_ID_MIN + 356)
Public Const KEY_AP_ALT_VAR_DEC = (KEY_ID_MIN + 357)
Public Const KEY_AP_VS_VAR_INC = (KEY_ID_MIN + 358)
Public Const KEY_AP_VS_VAR_DEC = (KEY_ID_MIN + 359)
Public Const KEY_AP_SPD_VAR_INC = (KEY_ID_MIN + 360)
Public Const KEY_AP_SPD_VAR_DEC = (KEY_ID_MIN + 361)
Public Const KEY_AP_N1_REF_INC = (KEY_ID_MIN + 362)
Public Const KEY_AP_N1_REF_DEC = (KEY_ID_MIN + 363)
Public Const KEY_MULTIPLAYER_TRACK_TOGGLE = (KEY_ID_MIN + 364)
Public Const KEY_MULTIPLAYER_PLAYER_TOGGLE = (KEY_ID_MIN + 365)
Public Const KEY_MULTIPLAYER_PLAYER_SNAP = (KEY_ID_MIN + 366)
Public Const KEY_MULTIPLAYER_GO_OBSERVER = (KEY_ID_MIN + 367)
Public Const KEY_MULTIPLAYER_CHAT = (KEY_ID_MIN + 368)
Public Const KEY_MULTIPLAYER_ACTIVATE_CHAT = (KEY_ID_MIN + 369)
Public Const KEY_PANEL_1 = (KEY_ID_MIN + 370)
Public Const KEY_PANEL_2 = (KEY_ID_MIN + 371)
Public Const KEY_PANEL_3 = (KEY_ID_MIN + 372)
Public Const KEY_PANEL_4 = (KEY_ID_MIN + 373)
Public Const KEY_PANEL_5 = (KEY_ID_MIN + 374)
Public Const KEY_PANEL_6 = (KEY_ID_MIN + 375)
Public Const KEY_PANEL_7 = (KEY_ID_MIN + 376)
Public Const KEY_PANEL_8 = (KEY_ID_MIN + 377)
Public Const KEY_PANEL_9 = (KEY_ID_MIN + 378)
Public Const KEY_AP_PANEL_MACH_HOLD = (KEY_ID_MIN + 379)
Public Const KEY_AP_MACH_VAR_INC = (KEY_ID_MIN + 380)
Public Const KEY_AP_MACH_VAR_DEC = (KEY_ID_MIN + 381)
Public Const KEY_AP_MACH_HOLD = (KEY_ID_MIN + 382)
Public Const KEY_MIXTURE1_SET = (KEY_ID_MIN + 383)
Public Const KEY_MIXTURE2_SET = (KEY_ID_MIN + 384)
Public Const KEY_MIXTURE3_SET = (KEY_ID_MIN + 385)
Public Const KEY_MIXTURE4_SET = (KEY_ID_MIN + 386)
Public Const KEY_PROP_PITCH1_SET = (KEY_ID_MIN + 387)
Public Const KEY_PROP_PITCH2_SET = (KEY_ID_MIN + 388)
Public Const KEY_PROP_PITCH3_SET = (KEY_ID_MIN + 389)
Public Const KEY_PROP_PITCH4_SET = (KEY_ID_MIN + 390)
Public Const KEY_MAGNETO1_OFF = (KEY_ID_MIN + 391)
Public Const KEY_STARTER1_OFF = (KEY_ID_MIN + 391)
Public Const KEY_MAGNETO1_RIGHT = (KEY_ID_MIN + 392)
Public Const KEY_STARTER1_START = (KEY_ID_MIN + 392)
Public Const KEY_MAGNETO1_LEFT = (KEY_ID_MIN + 393)
Public Const KEY_STARTER1_GEN = (KEY_ID_MIN + 393)
Public Const KEY_MAGNETO1_BOTH = (KEY_ID_MIN + 394)
Public Const KEY_MAGNETO1_START = (KEY_ID_MIN + 395)
Public Const KEY_STARTER1_SET = (KEY_ID_MIN + 396)
Public Const KEY_MAGNETO2_OFF = (KEY_ID_MIN + 397)
Public Const KEY_STARTER2_OFF = (KEY_ID_MIN + 397)
Public Const KEY_MAGNETO2_RIGHT = (KEY_ID_MIN + 398)
Public Const KEY_STARTER2_START = (KEY_ID_MIN + 398)
Public Const KEY_MAGNETO2_LEFT = (KEY_ID_MIN + 399)
Public Const KEY_STARTER2_GEN = (KEY_ID_MIN + 399)
Public Const KEY_MAGNETO2_BOTH = (KEY_ID_MIN + 400)
Public Const KEY_MAGNETO2_START = (KEY_ID_MIN + 401)
Public Const KEY_STARTER2_SET = (KEY_ID_MIN + 402)
Public Const KEY_MAGNETO3_OFF = (KEY_ID_MIN + 403)
Public Const KEY_STARTER3_OFF = (KEY_ID_MIN + 403)
Public Const KEY_MAGNETO3_RIGHT = (KEY_ID_MIN + 404)
Public Const KEY_STARTER3_START = (KEY_ID_MIN + 404)
Public Const KEY_MAGNETO3_LEFT = (KEY_ID_MIN + 405)
Public Const KEY_STARTER3_GEN = (KEY_ID_MIN + 405)
Public Const KEY_MAGNETO3_BOTH = (KEY_ID_MIN + 406)
Public Const KEY_MAGNETO3_START = (KEY_ID_MIN + 407)
Public Const KEY_STARTER3_SET = (KEY_ID_MIN + 408)
Public Const KEY_MAGNETO4_OFF = (KEY_ID_MIN + 409)
Public Const KEY_STARTER4_OFF = (KEY_ID_MIN + 409)
Public Const KEY_MAGNETO4_RIGHT = (KEY_ID_MIN + 410)
Public Const KEY_STARTER4_START = (KEY_ID_MIN + 410)
Public Const KEY_MAGNETO4_LEFT = (KEY_ID_MIN + 411)
Public Const KEY_STARTER4_GEN = (KEY_ID_MIN + 411)
Public Const KEY_MAGNETO4_BOTH = (KEY_ID_MIN + 412)
Public Const KEY_MAGNETO4_START = (KEY_ID_MIN + 413)
Public Const KEY_STARTER4_SET = (KEY_ID_MIN + 414)
Public Const KEY_AUTOCOORD_TOGGLE = (KEY_ID_MIN + 415)
Public Const KEY_AUTOCOORD_OFF = (KEY_ID_MIN + 416)
Public Const KEY_AUTOCOORD_ON = (KEY_ID_MIN + 417)
Public Const KEY_AUTOCOORD_SET = (KEY_ID_MIN + 418)
Public Const KEY_FUEL_SELECTOR_OFF = (KEY_ID_MIN + 419)
Public Const KEY_FUEL_SELECTOR_ALL = (KEY_ID_MIN + 420)
Public Const KEY_FUEL_SELECTOR_LEFT = (KEY_ID_MIN + 421)
Public Const KEY_FUEL_SELECTOR_RIGHT = (KEY_ID_MIN + 422)
Public Const KEY_FUEL_SELECTOR_LEFT_AUX = (KEY_ID_MIN + 423)
Public Const KEY_FUEL_SELECTOR_RIGHT_AUX = (KEY_ID_MIN + 424)
Public Const KEY_FUEL_SELECTOR_CENTER = (KEY_ID_MIN + 425)
Public Const KEY_FUEL_SELECTOR_SET = (KEY_ID_MIN + 426)
Public Const KEY_THROTTLE1_FULL = (KEY_ID_MIN + 427)
Public Const KEY_THROTTLE1_INCR = (KEY_ID_MIN + 428)
Public Const KEY_THROTTLE1_INCR_SMALL = (KEY_ID_MIN + 429)
Public Const KEY_THROTTLE1_DECR = (KEY_ID_MIN + 430)
Public Const KEY_THROTTLE1_CUT = (KEY_ID_MIN + 431)
Public Const KEY_THROTTLE2_FULL = (KEY_ID_MIN + 432)
Public Const KEY_THROTTLE2_INCR = (KEY_ID_MIN + 433)
Public Const KEY_THROTTLE2_INCR_SMALL = (KEY_ID_MIN + 434)
Public Const KEY_THROTTLE2_DECR = (KEY_ID_MIN + 435)
Public Const KEY_THROTTLE2_CUT = (KEY_ID_MIN + 436)
Public Const KEY_THROTTLE3_FULL = (KEY_ID_MIN + 437)
Public Const KEY_THROTTLE3_INCR = (KEY_ID_MIN + 438)
Public Const KEY_THROTTLE3_INCR_SMALL = (KEY_ID_MIN + 439)
Public Const KEY_THROTTLE3_DECR = (KEY_ID_MIN + 440)
Public Const KEY_THROTTLE3_CUT = (KEY_ID_MIN + 441)
Public Const KEY_THROTTLE4_FULL = (KEY_ID_MIN + 442)
Public Const KEY_THROTTLE4_INCR = (KEY_ID_MIN + 443)
Public Const KEY_THROTTLE4_INCR_SMALL = (KEY_ID_MIN + 444)
Public Const KEY_THROTTLE4_DECR = (KEY_ID_MIN + 445)
Public Const KEY_THROTTLE4_CUT = (KEY_ID_MIN + 446)
Public Const KEY_MIXTURE1_RICH = (KEY_ID_MIN + 447)
Public Const KEY_MIXTURE1_INCR = (KEY_ID_MIN + 448)
Public Const KEY_MIXTURE1_INCR_SMALL = (KEY_ID_MIN + 449)
Public Const KEY_MIXTURE1_DECR = (KEY_ID_MIN + 450)
Public Const KEY_MIXTURE1_LEAN = (KEY_ID_MIN + 451)
Public Const KEY_MIXTURE2_RICH = (KEY_ID_MIN + 452)
Public Const KEY_MIXTURE2_INCR = (KEY_ID_MIN + 453)
Public Const KEY_MIXTURE2_INCR_SMALL = (KEY_ID_MIN + 454)
Public Const KEY_MIXTURE2_DECR = (KEY_ID_MIN + 455)
Public Const KEY_MIXTURE2_LEAN = (KEY_ID_MIN + 456)
Public Const KEY_MIXTURE3_RICH = (KEY_ID_MIN + 457)
Public Const KEY_MIXTURE3_INCR = (KEY_ID_MIN + 458)
Public Const KEY_MIXTURE3_INCR_SMALL = (KEY_ID_MIN + 459)
Public Const KEY_MIXTURE3_DECR = (KEY_ID_MIN + 460)
Public Const KEY_MIXTURE3_LEAN = (KEY_ID_MIN + 461)
Public Const KEY_MIXTURE4_RICH = (KEY_ID_MIN + 462)
Public Const KEY_MIXTURE4_INCR = (KEY_ID_MIN + 463)
Public Const KEY_MIXTURE4_INCR_SMALL = (KEY_ID_MIN + 464)
Public Const KEY_MIXTURE4_DECR = (KEY_ID_MIN + 465)
Public Const KEY_MIXTURE4_LEAN = (KEY_ID_MIN + 466)
Public Const KEY_PROP_PITCH1_LO = (KEY_ID_MIN + 467)
Public Const KEY_PROP_PITCH1_INCR = (KEY_ID_MIN + 468)
Public Const KEY_PROP_PITCH1_INCR_SMALL = (KEY_ID_MIN + 469)
Public Const KEY_PROP_PITCH1_DECR = (KEY_ID_MIN + 470)
Public Const KEY_PROP_PITCH1_HI = (KEY_ID_MIN + 471)
Public Const KEY_PROP_PITCH2_LO = (KEY_ID_MIN + 472)
Public Const KEY_PROP_PITCH2_INCR = (KEY_ID_MIN + 473)
Public Const KEY_PROP_PITCH2_INCR_SMALL = (KEY_ID_MIN + 474)
Public Const KEY_PROP_PITCH2_DECR = (KEY_ID_MIN + 475)
Public Const KEY_PROP_PITCH2_HI = (KEY_ID_MIN + 476)
Public Const KEY_PROP_PITCH3_LO = (KEY_ID_MIN + 477)
Public Const KEY_PROP_PITCH3_INCR = (KEY_ID_MIN + 478)
Public Const KEY_PROP_PITCH3_INCR_SMALL = (KEY_ID_MIN + 479)
Public Const KEY_PROP_PITCH3_DECR = (KEY_ID_MIN + 480)
Public Const KEY_PROP_PITCH3_HI = (KEY_ID_MIN + 481)
Public Const KEY_PROP_PITCH4_LO = (KEY_ID_MIN + 482)
Public Const KEY_PROP_PITCH4_INCR = (KEY_ID_MIN + 483)
Public Const KEY_PROP_PITCH4_INCR_SMALL = (KEY_ID_MIN + 484)
Public Const KEY_PROP_PITCH4_DECR = (KEY_ID_MIN + 485)
Public Const KEY_PROP_PITCH4_HI = (KEY_ID_MIN + 486)
Public Const KEY_MAGNETO_OFF = (KEY_ID_MIN + 487)
Public Const KEY_STARTER_OFF = (KEY_ID_MIN + 487)
Public Const KEY_MAGNETO_RIGHT = (KEY_ID_MIN + 488)
Public Const KEY_STARTER_START = (KEY_ID_MIN + 488)
Public Const KEY_MAGNETO_LEFT = (KEY_ID_MIN + 489)
Public Const KEY_STARTER_GEN = (KEY_ID_MIN + 489)
Public Const KEY_MAGNETO_BOTH = (KEY_ID_MIN + 490)
Public Const KEY_MAGNETO_START = (KEY_ID_MIN + 491)
Public Const KEY_STARTER_SET = (KEY_ID_MIN + 492)
Public Const KEY_ANTI_ICE_ON = (KEY_ID_MIN + 493)
Public Const KEY_ANTI_ICE_OFF = (KEY_ID_MIN + 494)
Public Const KEY_ANTI_ICE_SET = (KEY_ID_MIN + 495)
Public Const KEY_EGT_INC = (KEY_ID_MIN + 496)
Public Const KEY_EGT_DEC = (KEY_ID_MIN + 497)
Public Const KEY_EGT_SET = (KEY_ID_MIN + 498)
Public Const KEY_AP_ALT_VAR_SET_METRIC = (KEY_ID_MIN + 499)
Public Const KEY_AP_VS_VAR_SET_ENGLISH = (KEY_ID_MIN + 500)
Public Const KEY_AP_SPD_VAR_SET = (KEY_ID_MIN + 501)
Public Const KEY_AP_MACH_VAR_SET = (KEY_ID_MIN + 502)
Public Const KEY_ADF_CARD_SET = (KEY_ID_MIN + 503)
Public Const KEY_KOHLSMAN_SET = (KEY_ID_MIN + 504)
Public Const KEY_SIM_RATE_SET = (KEY_ID_MIN + 505)
Public Const KEY_HEADING_BUG_SET = (KEY_ID_MIN + 506)
Public Const KEY_TRUE_AIRSPEED_CAL_SET = (KEY_ID_MIN + 507)
Public Const KEY_CLOCK_HOURS_SET = (KEY_ID_MIN + 508)
Public Const KEY_CLOCK_MINUTES_SET = (KEY_ID_MIN + 509)
Public Const KEY_GYRO_DRIFT_SET = (KEY_ID_MIN + 510)
Public Const KEY_ADF_EXTENDED_SET = (KEY_ID_MIN + 511)
Public Const KEY_SLEW_SET = (KEY_ID_MIN + 512)
Public Const KEY_SMOKE_ON = (KEY_ID_MIN + 513)
Public Const KEY_SMOKE_OFF = (KEY_ID_MIN + 514)
Public Const KEY_SMOKE_SET = (KEY_ID_MIN + 515)
Public Const KEY_STROBES_ON = (KEY_ID_MIN + 516)
Public Const KEY_STROBES_OFF = (KEY_ID_MIN + 517)
Public Const KEY_STROBES_SET = (KEY_ID_MIN + 518)
Public Const KEY_PAUSE_SET = (KEY_ID_MIN + 519)
Public Const KEY_PANEL_LIGHTS_ON = (KEY_ID_MIN + 520)
Public Const KEY_PANEL_LIGHTS_OFF = (KEY_ID_MIN + 521)
Public Const KEY_PANEL_LIGHTS_SET = (KEY_ID_MIN + 522)
Public Const KEY_LANDING_LIGHTS_ON = (KEY_ID_MIN + 523)
Public Const KEY_LANDING_LIGHTS_OFF = (KEY_ID_MIN + 524)
Public Const KEY_LANDING_LIGHTS_SET = (KEY_ID_MIN + 525)
Public Const KEY_SOUND_ON = (KEY_ID_MIN + 526)
Public Const KEY_SOUND_OFF = (KEY_ID_MIN + 527)
Public Const KEY_SPOILERS_ON = (KEY_ID_MIN + 528)
Public Const KEY_SPOILERS_OFF = (KEY_ID_MIN + 529)
Public Const KEY_SPOILERS_ARM_ON = (KEY_ID_MIN + 530)
Public Const KEY_SPOILERS_ARM_OFF = (KEY_ID_MIN + 531)
Public Const KEY_SPOILERS_ARM_SET = (KEY_ID_MIN + 532)
Public Const KEY_YAW_DAMPER_ON = (KEY_ID_MIN + 533)
Public Const KEY_YAW_DAMPER_OFF = (KEY_ID_MIN + 534)
Public Const KEY_YAW_DAMPER_SET = (KEY_ID_MIN + 535)
Public Const KEY_PITOT_HEAT_ON = (KEY_ID_MIN + 536)
Public Const KEY_PITOT_HEAT_OFF = (KEY_ID_MIN + 537)
Public Const KEY_PITOT_HEAT_SET = (KEY_ID_MIN + 538)
Public Const KEY_ZULU_HOURS_SET = (KEY_ID_MIN + 539)
Public Const KEY_ZULU_MINUTES_SET = (KEY_ID_MIN + 540)
Public Const KEY_ZULU_DAY_SET = (KEY_ID_MIN + 541)
Public Const KEY_ZULU_YEAR_SET = (KEY_ID_MIN + 542)
Public Const KEY_GEAR_UP = (KEY_ID_MIN + 543)
Public Const KEY_GEAR_DOWN = (KEY_ID_MIN + 544)
Public Const KEY_EGT1_INC = (KEY_ID_MIN + 545)
Public Const KEY_EGT1_DEC = (KEY_ID_MIN + 546)
Public Const KEY_EGT1_SET = (KEY_ID_MIN + 547)
Public Const KEY_EGT2_INC = (KEY_ID_MIN + 548)
Public Const KEY_EGT2_DEC = (KEY_ID_MIN + 549)
Public Const KEY_EGT2_SET = (KEY_ID_MIN + 550)
Public Const KEY_EGT3_INC = (KEY_ID_MIN + 551)
Public Const KEY_EGT3_DEC = (KEY_ID_MIN + 552)
Public Const KEY_EGT3_SET = (KEY_ID_MIN + 553)
Public Const KEY_EGT4_INC = (KEY_ID_MIN + 554)
Public Const KEY_EGT4_DEC = (KEY_ID_MIN + 555)
Public Const KEY_EGT4_SET = (KEY_ID_MIN + 556)
Public Const KEY_AP_AIRSPEED_ON = (KEY_ID_MIN + 557)
Public Const KEY_AP_AIRSPEED_OFF = (KEY_ID_MIN + 558)
Public Const KEY_AP_AIRSPEED_SET = (KEY_ID_MIN + 559)
Public Const KEY_AP_MACH_ON = (KEY_ID_MIN + 560)
Public Const KEY_AP_MACH_OFF = (KEY_ID_MIN + 561)
Public Const KEY_AP_MACH_SET = (KEY_ID_MIN + 562)
Public Const KEY_AP_VS_HOLD = (KEY_ID_MIN + 563)
Public Const KEY_AP_VS_ON = (KEY_ID_MIN + 564)
Public Const KEY_AP_VS_OFF = (KEY_ID_MIN + 565)
Public Const KEY_AP_VS_SET = (KEY_ID_MIN + 566)
Public Const KEY_AP_PANEL_ALTITUDE_ON = (KEY_ID_MIN + 567)
Public Const KEY_AP_PANEL_ALTITUDE_OFF = (KEY_ID_MIN + 568)
Public Const KEY_AP_PANEL_ALTITUDE_SET = (KEY_ID_MIN + 569)
Public Const KEY_AP_PANEL_HEADING_ON = (KEY_ID_MIN + 570)
Public Const KEY_AP_PANEL_HEADING_OFF = (KEY_ID_MIN + 571)
Public Const KEY_AP_PANEL_HEADING_SET = (KEY_ID_MIN + 572)
Public Const KEY_AP_PANEL_MACH_ON = (KEY_ID_MIN + 573)
Public Const KEY_AP_PANEL_MACH_OFF = (KEY_ID_MIN + 574)
Public Const KEY_AP_PANEL_MACH_SET = (KEY_ID_MIN + 575)
Public Const KEY_AP_PANEL_SPEED_ON = (KEY_ID_MIN + 576)
Public Const KEY_AP_PANEL_SPEED_OFF = (KEY_ID_MIN + 577)
Public Const KEY_AP_PANEL_SPEED_SET = (KEY_ID_MIN + 578)
Public Const KEY_AP_PANEL_VS_ON = (KEY_ID_MIN + 579)
Public Const KEY_AP_PANEL_VS_OFF = (KEY_ID_MIN + 580)
Public Const KEY_AP_PANEL_VS_SET = (KEY_ID_MIN + 581)
Public Const KEY_SEE_OWN_AC_TOGGLE = (KEY_ID_MIN + 582)
Public Const KEY_SEE_OWN_AC_ON = (KEY_ID_MIN + 583)
Public Const KEY_SEE_OWN_AC_OFF = (KEY_ID_MIN + 584)
Public Const KEY_SEE_OWN_AC_SET = (KEY_ID_MIN + 585)
Public Const KEY_ADF_LOWRANGE_SET = (KEY_ID_MIN + 586)
Public Const KEY_ADF_HIGHRANGE_SET = (KEY_ID_MIN + 587)
Public Const KEY_AP_ALT_VAR_SET_ENGLISH = (KEY_ID_MIN + 588)
Public Const KEY_AP_VS_VAR_SET_METRIC = (KEY_ID_MIN + 589)
Public Const KEY_MAGNETO1_DECR = (KEY_ID_MIN + 590)
Public Const KEY_MAGNETO1_INCR = (KEY_ID_MIN + 591)
Public Const KEY_MAGNETO2_DECR = (KEY_ID_MIN + 592)
Public Const KEY_MAGNETO2_INCR = (KEY_ID_MIN + 593)
Public Const KEY_MAGNETO3_DECR = (KEY_ID_MIN + 594)
Public Const KEY_MAGNETO3_INCR = (KEY_ID_MIN + 595)
Public Const KEY_MAGNETO4_DECR = (KEY_ID_MIN + 596)
Public Const KEY_MAGNETO4_INCR = (KEY_ID_MIN + 597)
Public Const KEY_GUNSIGHT_SEL = (KEY_ID_MIN + 599)
Public Const KEY_GUNSIGHT_TOGGLE = (KEY_ID_MIN + 600)
Public Const KEY_VIEW_FORWARD_UP = (KEY_ID_MIN + 601)
Public Const KEY_VIEW_FORWARD_RIGHT_UP = (KEY_ID_MIN + 602)
Public Const KEY_VIEW_RIGHT_UP = (KEY_ID_MIN + 603)
Public Const KEY_VIEW_REAR_RIGHT_UP = (KEY_ID_MIN + 604)
Public Const KEY_VIEW_REAR_UP = (KEY_ID_MIN + 605)
Public Const KEY_VIEW_REAR_LEFT_UP = (KEY_ID_MIN + 606)
Public Const KEY_VIEW_LEFT_UP = (KEY_ID_MIN + 607)
Public Const KEY_VIEW_FORWARD_LEFT_UP = (KEY_ID_MIN + 608)
Public Const KEY_VIEW_UP = (KEY_ID_MIN + 609)
Public Const KEY_SKIP_ACTION = (KEY_ID_MIN + 610)
Public Const KEY_VIEW_RESET = (KEY_ID_MIN + 611)
Public Const KEY_FIRE_ALL_GUNS = (KEY_ID_MIN + 620)
Public Const KEY_FIRE_PRIMARY_GUNS = (KEY_ID_MIN + 621)
Public Const KEY_FIRE_SECONDARY_GUNS = (KEY_ID_MIN + 622)
Public Const KEY_COWLFLAP1_SET = (KEY_ID_MIN + 626)
Public Const KEY_COWLFLAP2_SET = (KEY_ID_MIN + 627)
Public Const KEY_COWLFLAP3_SET = (KEY_ID_MIN + 628)
Public Const KEY_COWLFLAP4_SET = (KEY_ID_MIN + 629)
Public Const KEY_TOGGLE_RADAR = (KEY_ID_MIN + 634)
Public Const KEY_ATC_MENU_1 = (KEY_ID_MIN + 636)
Public Const KEY_ATC_MENU_2 = (KEY_ID_MIN + 637)
Public Const KEY_ATC_MENU_3 = (KEY_ID_MIN + 638)
Public Const KEY_ATC_MENU_4 = (KEY_ID_MIN + 639)
Public Const KEY_ATC_MENU_5 = (KEY_ID_MIN + 640)
Public Const KEY_ATC_MENU_6 = (KEY_ID_MIN + 641)
Public Const KEY_ATC_MENU_7 = (KEY_ID_MIN + 642)
Public Const KEY_ATC_MENU_8 = (KEY_ID_MIN + 643)
Public Const KEY_ATC_MENU_9 = (KEY_ID_MIN + 644)
Public Const KEY_ATC_MENU_0 = (KEY_ID_MIN + 645)
Public Const KEY_VIEW_AUX_00 = (KEY_ID_MIN + 646)
Public Const KEY_VIEW_AUX_01 = (KEY_ID_MIN + 647)
Public Const KEY_VIEW_AUX_02 = (KEY_ID_MIN + 648)
Public Const KEY_VIEW_AUX_03 = (KEY_ID_MIN + 649)
Public Const KEY_VIEW_AUX_04 = (KEY_ID_MIN + 650)
Public Const KEY_VIEW_AUX_05 = (KEY_ID_MIN + 651)
Public Const KEY_INVOKE_HELP = (KEY_ID_MIN + 659)
Public Const KEY_SELECT_NEXT_TARGET = (KEY_ID_MIN + 660)
Public Const KEY_TOGGLE_PADLOCK = (KEY_ID_MIN + 661)
Public Const KEY_UNLOCK_TARGET = (KEY_ID_MIN + 662)
Public Const KEY_TOGGLE_AIRCRAFT_LABELS = (KEY_ID_MIN + 663)
Public Const KEY_TOGGLE_DAMAGE_TEXT = (KEY_ID_MIN + 664)
Public Const KEY_TOGGLE_ENEMY_INDICATOR = (KEY_ID_MIN + 665)
Public Const KEY_WAR_EMERGENCY_POWER = (KEY_ID_MIN + 666)
Public Const KEY_BAIL_OUT = (KEY_ID_MIN + 667)
Public Const KEY_TOGGLE_RADIO = (KEY_ID_MIN + 668)
Public Const KEY_KEYBOARD_OVERLAY = (KEY_ID_MIN + 669)
Public Const KEY_CHASE_VIEW = (KEY_ID_MIN + 670)
Public Const KEY_OTHER_AIRCRAFT_VIEW = (KEY_ID_MIN + 671)
Public Const KEY_BOMB_VIEW = (KEY_ID_MIN + 672)
Public Const KEY_HUD_UNITS = (KEY_ID_MIN + 673)
Public Const KEY_HUD_COLOR = (KEY_ID_MIN + 674)
Public Const KEY_LETTERBOX = (KEY_ID_MIN + 687)
Public Const KEY_ENGINE_AUTO_START = (KEY_ID_MIN + 688)
Public Const KEY_THROTTLE_10 = (KEY_ID_MIN + 689)
Public Const KEY_THROTTLE_20 = (KEY_ID_MIN + 690)
Public Const KEY_THROTTLE_30 = (KEY_ID_MIN + 691)
Public Const KEY_THROTTLE_40 = (KEY_ID_MIN + 692)
Public Const KEY_THROTTLE_50 = (KEY_ID_MIN + 693)
Public Const KEY_THROTTLE_60 = (KEY_ID_MIN + 694)
Public Const KEY_THROTTLE_70 = (KEY_ID_MIN + 695)
Public Const KEY_THROTTLE_80 = (KEY_ID_MIN + 696)
Public Const KEY_THROTTLE_90 = (KEY_ID_MIN + 697)
Public Const KEY_FORCE_END = (KEY_ID_MIN + 698)
Public Const KEY_FUEL_PUMP = (KEY_ID_MIN + 701)
Public Const KEY_ENGINE_PRIMER = (KEY_ID_MIN + 702)
Public Const KEY_TOGGLE_BEACON_LIGHTS = (KEY_ID_MIN + 703)
Public Const KEY_TOGGLE_TAXI_LIGHTS = (KEY_ID_MIN + 704)
Public Const KEY_TOGGLE_MASTER_BATTERY = (KEY_ID_MIN + 705)
Public Const KEY_TOGGLE_MASTER_ALTERNATOR = (KEY_ID_MIN + 706)
Public Const KEY_INC_COWL_FLAPS = (KEY_ID_MIN + 707)
Public Const KEY_DEC_COWL_FLAPS = (KEY_ID_MIN + 708)
Public Const KEY_OVERLAYMENU = (KEY_ID_MIN + 731)
Public Const KEY_USERINTERRUPT = (KEY_ID_MIN + 732)
Public Const KEY_SELECT_PREV_TARGET = (KEY_ID_MIN + 733)
Public Const KEY_STOP_PRIMARY_GUNS = (KEY_ID_MIN + 734)
Public Const KEY_STOP_SECONDARY_GUNS = (KEY_ID_MIN + 735)
Public Const KEY_STOP_ALL_GUNS = (KEY_ID_MIN + 736)
Public Const KEY_SP_MULTIPLAYER_SCORE_DISPLAY = (KEY_ID_MIN + 737)
Public Const KEY_VIEW_SNAP_FORWARD = (KEY_ID_MIN + 738)
Public Const KEY_VIEW_SNAP_REAR = (KEY_ID_MIN + 739)
Public Const KEY_AILERON_TRIM_LEFT = (KEY_ID_MIN + 740)
Public Const KEY_AILERON_TRIM_RIGHT = (KEY_ID_MIN + 741)
Public Const KEY_RUDDER_TRIM_LEFT = (KEY_ID_MIN + 742)
Public Const KEY_RUDDER_TRIM_RIGHT = (KEY_ID_MIN + 743)
Public Const KEY_RADIO_COMMNAV1_TEST_TOGGLE = (KEY_ID_MIN + 744)
Public Const KEY_RADIO_COMMNAV2_TEST_TOGGLE = (KEY_ID_MIN + 745)
Public Const KEY_RADIO_COMM1_AUTOSWITCH_TOGGLE = (KEY_ID_MIN + 746)
Public Const KEY_RADIO_NAV1_AUTOSWITCH_TOGGLE = (KEY_ID_MIN + 747)
Public Const KEY_RADIO_COMM2_AUTOSWITCH_TOGGLE = (KEY_ID_MIN + 748)
Public Const KEY_RADIO_NAV2_AUTOSWITCH_TOGGLE = (KEY_ID_MIN + 749)
Public Const KEY_DME_TOGGLE = (KEY_ID_MIN + 750)
Public Const KEY_TOGGLE_PROP_SYNC = (KEY_ID_MIN + 751)
Public Const KEY_TOGGLE_FLIGHT_DIRECTOR = (KEY_ID_MIN + 752)
Public Const KEY_SYNC_FLIGHT_DIRECTOR_PITCH = (KEY_ID_MIN + 753)
Public Const KEY_TOGGLE_ELECTRIC_VACUUM_PUMP = (KEY_ID_MIN + 754)
Public Const KEY_AXIS_PROPELLER_SET = (KEY_ID_MIN + 755)
Public Const KEY_AXIS_MIXTURE_SET = (KEY_ID_MIN + 756)
Public Const KEY_TOGGLE_AVIONICS_MASTER = (KEY_ID_MIN + 757)
Public Const KEY_INC_CONCORDE_NOSE_VISOR = (KEY_ID_MIN + 758)
Public Const KEY_DEC_CONCORDE_NOSE_VISOR = (KEY_ID_MIN + 759)
Public Const KEY_TOGGLE_AFTERBURNER = (KEY_ID_MIN + 760)
Public Const KEY_TOGGLE_ARM_AUTOFEATHER = (KEY_ID_MIN + 761)
Public Const KEY_INC_AUTOBRAKE_CONTROL = (KEY_ID_MIN + 762)
Public Const KEY_DEC_AUTOBRAKE_CONTROL = (KEY_ID_MIN + 763)
Public Const KEY_TOGGLE_STARTER1 = (KEY_ID_MIN + 764)
Public Const KEY_TOGGLE_STARTER2 = (KEY_ID_MIN + 765)
Public Const KEY_TOGGLE_STARTER3 = (KEY_ID_MIN + 766)
Public Const KEY_TOGGLE_STARTER4 = (KEY_ID_MIN + 767)
Public Const KEY_TOGGLE_ALL_STARTERS = (KEY_ID_MIN + 768)
Public Const KEY_TOGGLE_VACUUM_FAILURE = (KEY_ID_MIN + 769)
Public Const KEY_TOGGLE_ELECTRICAL_FAILURE = (KEY_ID_MIN + 770)
Public Const KEY_TOGGLE_PITOT_BLOCKAGE = (KEY_ID_MIN + 771)
Public Const KEY_TOGGLE_STATIC_PORT_BLOCKAGE = (KEY_ID_MIN + 772)
Public Const KEY_TOGGLE_HYDRAULIC_FAILURE = (KEY_ID_MIN + 773)
Public Const KEY_TOGGLE_TOTAL_BRAKE_FAILURE = (KEY_ID_MIN + 774)
Public Const KEY_TOGGLE_LEFT_BRAKE_FAILURE = (KEY_ID_MIN + 775)
Public Const KEY_TOGGLE_RIGHT_BRAKE_FAILURE = (KEY_ID_MIN + 776)
Public Const KEY_TOGGLE_ENGINE1_FAILURE = (KEY_ID_MIN + 777)
Public Const KEY_TOGGLE_ENGINE2_FAILURE = (KEY_ID_MIN + 778)
Public Const KEY_TOGGLE_ENGINE3_FAILURE = (KEY_ID_MIN + 779)
Public Const KEY_TOGGLE_ENGINE4_FAILURE = (KEY_ID_MIN + 780)
Public Const KEY_TOGGLE_ALTERNATE_STATIC = (KEY_ID_MIN + 781)
Public Const KEY_ATTITUDE_BARS_POSITION_INC = (KEY_ID_MIN + 782)
Public Const KEY_ATTITUDE_BARS_POSITION_DEC = (KEY_ID_MIN + 783)
Public Const KEY_TOGGLE_RAD_INS_SWITCH = (KEY_ID_MIN + 784)
Public Const KEY_DECISION_HEIGHT_INC = (KEY_ID_MIN + 785)
Public Const KEY_DECISION_HEIGHT_DEC = (KEY_ID_MIN + 786)
Public Const KEY_LOW_HIGHT_WARNING_SET = (KEY_ID_MIN + 787)
Public Const KEY_LOW_HIGHT_WARNING_GAUGE_WILL_SET = (KEY_ID_MIN + 788)
Public Const KEY_SET_FUEL_TRANSFER_FORWARD = (KEY_ID_MIN + 789)
Public Const KEY_SET_FUEL_TRANSFER_AFT = (KEY_ID_MIN + 790)
Public Const KEY_SET_FUEL_TRANSFER_AUTO = (KEY_ID_MIN + 791)
Public Const KEY_SET_FUEL_TRANSFER_OFF = (KEY_ID_MIN + 792)
Public Const KEY_INC_COWL_FLAPS1 = (KEY_ID_MIN + 793)
Public Const KEY_DEC_COWL_FLAPS1 = (KEY_ID_MIN + 794)
Public Const KEY_INC_COWL_FLAPS2 = (KEY_ID_MIN + 795)
Public Const KEY_DEC_COWL_FLAPS2 = (KEY_ID_MIN + 796)
Public Const KEY_INC_COWL_FLAPS3 = (KEY_ID_MIN + 797)
Public Const KEY_DEC_COWL_FLAPS3 = (KEY_ID_MIN + 798)
Public Const KEY_INC_COWL_FLAPS4 = (KEY_ID_MIN + 799)
Public Const KEY_DEC_COWL_FLAPS4 = (KEY_ID_MIN + 800)
Public Const KEY_TOGGLE_STRUCTURAL_DEICE = (KEY_ID_MIN + 801)
Public Const KEY_TOGGLE_PROPELLER_DEICE = (KEY_ID_MIN + 802)
Public Const KEY_TOGGLE_ELECT_FUEL_PUMP = (KEY_ID_MIN + 803)
Public Const KEY_TOGGLE_ELECT_FUEL_PUMP1 = (KEY_ID_MIN + 804)
Public Const KEY_TOGGLE_ELECT_FUEL_PUMP2 = (KEY_ID_MIN + 805)
Public Const KEY_TOGGLE_ELECT_FUEL_PUMP3 = (KEY_ID_MIN + 806)
Public Const KEY_TOGGLE_ELECT_FUEL_PUMP4 = (KEY_ID_MIN + 807)
Public Const KEY_TOGGLE_PRIMER = (KEY_ID_MIN + 808)
Public Const KEY_TOGGLE_PRIMER1 = (KEY_ID_MIN + 809)
Public Const KEY_TOGGLE_PRIMER2 = (KEY_ID_MIN + 810)
Public Const KEY_TOGGLE_PRIMER3 = (KEY_ID_MIN + 811)
Public Const KEY_TOGGLE_PRIMER4 = (KEY_ID_MIN + 812)
Public Const KEY_ENGINE_FUELFLOW_BUG_POSITION1 = (KEY_ID_MIN + 813)
Public Const KEY_ENGINE_FUELFLOW_BUG_POSITION2 = (KEY_ID_MIN + 814)
Public Const KEY_ENGINE_FUELFLOW_BUG_POSITION3 = (KEY_ID_MIN + 815)
Public Const KEY_ENGINE_FUELFLOW_BUG_POSITION4 = (KEY_ID_MIN + 816)
Public Const KEY_AUTOPILOT_AIRSPEED_HOLD_CURRENT = (KEY_ID_MIN + 817)
Public Const KEY_AUTOPILOT_AIRSPEED_ACQUIRE = (KEY_ID_MIN + 818)
Public Const KEY_AUTOPILOT_PANEL_AIRSPEED_SET = (KEY_ID_MIN + 819)
Public Const KEY_AUTOPILOT_MACH_HOLD_CURRENT = (KEY_ID_MIN + 820)
Public Const KEY_AUTOPILOT_PANEL_MAX_SPEED = (KEY_ID_MIN + 821)
Public Const KEY_AUTOPILOT_PANEL_CRUISE_SPEED = (KEY_ID_MIN + 822)
Public Const KEY_TOGGLE_AFTERBURNER1 = (KEY_ID_MIN + 823)
Public Const KEY_TOGGLE_AFTERBURNER2 = (KEY_ID_MIN + 824)
Public Const KEY_TOGGLE_AFTERBURNER3 = (KEY_ID_MIN + 825)
Public Const KEY_TOGGLE_AFTERBURNER4 = (KEY_ID_MIN + 826)
Public Const KEY_TOGGLE_ALTERNATOR1 = (KEY_ID_MIN + 827)
Public Const KEY_TOGGLE_ALTERNATOR2 = (KEY_ID_MIN + 828)
Public Const KEY_TOGGLE_ALTERNATOR3 = (KEY_ID_MIN + 829)
Public Const KEY_TOGGLE_ALTERNATOR4 = (KEY_ID_MIN + 830)
Public Const KEY_VOR1_OBI_FAST_DEC = (KEY_ID_MIN + 831)
Public Const KEY_VOR1_OBI_FAST_INC = (KEY_ID_MIN + 832)
Public Const KEY_VOR2_OBI_FAST_DEC = (KEY_ID_MIN + 833)
Public Const KEY_VOR2_OBI_FAST_INC = (KEY_ID_MIN + 834)
Public Const KEY_COM_STBY_RADIO_SET = (KEY_ID_MIN + 835)
Public Const KEY_COM_STBY_RADIO_SWITCH_TO = (KEY_ID_MIN + 836)
Public Const KEY_COM_RADIO_SWAP = KEY_COM_STBY_RADIO_SWITCH_TO
Public Const KEY_TOGGLE_ATTITUDE_CAGE = (KEY_ID_MIN + 837)
Public Const KEY_TOGGLE_MASTER_BATTERY_ALTERNATOR = (KEY_ID_MIN + 838)
Public Const KEY_TOGGLE_GPS_DRIVES_NAV1 = (KEY_ID_MIN + 839)
Public Const KEY_TOGGLE_LOGO_LIGHTS = (KEY_ID_MIN + 840)
Public Const KEY_TOGGLE_RECOGNITION_LIGHTS = (KEY_ID_MIN + 841)
Public Const KEY_TOGGLE_WING_LIGHTS = (KEY_ID_MIN + 842)
Public Const KEY_TOGGLE_NAV_LIGHTS = (KEY_ID_MIN + 843)
Public Const KEY_HELI_BEEP_INCREASE = (KEY_ID_MIN + 844)
Public Const KEY_HELI_BEEP_DECREASE = (KEY_ID_MIN + 845)
Public Const KEY_AXIS_SPOILER_SET = (KEY_ID_MIN + 846)
Public Const KEY_CONCORDE_NOSE_VISOR_FULL_EXT = (KEY_ID_MIN + 847)
Public Const KEY_CONCORDE_NOSE_VISOR_FULL_RET = (KEY_ID_MIN + 848)
Public Const KEY_LOD_ZOOM_IN = (KEY_ID_MIN + 849)
Public Const KEY_LOD_ZOOM_OUT = (KEY_ID_MIN + 850)
Public Const KEY_AXIS_LEFT_BRAKE_SET = (KEY_ID_MIN + 851)
Public Const KEY_AXIS_RIGHT_BRAKE_SET = (KEY_ID_MIN + 852)
Public Const KEY_TOGGLE_AIRCRAFT_EXIT = (KEY_ID_MIN + 853)
Public Const KEY_TOGGLE_WING_FOLD = (KEY_ID_MIN + 854)
Public Const KEY_TOGGLE_TAIL_HOOK_HANDLE = (KEY_ID_MIN + 855)
Public Const KEY_RELEASE_DROP_TANK_ALL = (KEY_ID_MIN + 856)
Public Const KEY_RELEASE_DROP_TANK_1 = (KEY_ID_MIN + 857)
Public Const KEY_RELEASE_DROP_TANK_2 = (KEY_ID_MIN + 858)
Public Const KEY_MAGNETO_SET = (KEY_ID_MIN + 863)
Public Const KEY_MAGNETO1_SET = (KEY_ID_MIN + 864)
Public Const KEY_MAGNETO2_SET = (KEY_ID_MIN + 865)
Public Const KEY_MAGNETO3_SET = (KEY_ID_MIN + 866)
Public Const KEY_MAGNETO4_SET = (KEY_ID_MIN + 867)
Public Const KEY_PANEL_HUD_TOGGLE = (KEY_ID_MIN + 868)
Public Const KEY_TOOLTIP_UNITS_SET = (KEY_ID_MIN + 869)
Public Const KEY_TOOLTIP_UNITS_TOGGLE = (KEY_ID_MIN + 870)
Public Const KEY_VIEW_SNAP_PANEL = (KEY_ID_MIN + 877)
Public Const KEY_VIEW_SNAP_PANEL_RESET = (KEY_ID_MIN + 878)
Public Const KEY_PAN_RESET_COCKPIT = (KEY_ID_MIN + 879)
Public Const KEY_PAN_VIEW = (KEY_ID_MIN + 880)
Public Const KEY_SNAP_VIEW = (KEY_ID_MIN + 881)
Public Const KEY_AXIS_THROTTLE1_SET = (KEY_ID_MIN + 884)
Public Const KEY_AXIS_PROPELLER1_SET = (KEY_ID_MIN + 885)
Public Const KEY_AXIS_MIXTURE1_SET = (KEY_ID_MIN + 886)
Public Const KEY_AXIS_THROTTLE2_SET = (KEY_ID_MIN + 887)
Public Const KEY_AXIS_PROPELLER2_SET = (KEY_ID_MIN + 888)
Public Const KEY_AXIS_MIXTURE2_SET = (KEY_ID_MIN + 889)
Public Const KEY_AXIS_THROTTLE3_SET = (KEY_ID_MIN + 890)
Public Const KEY_AXIS_PROPELLER3_SET = (KEY_ID_MIN + 891)
Public Const KEY_AXIS_MIXTURE3_SET = (KEY_ID_MIN + 892)
Public Const KEY_AXIS_THROTTLE4_SET = (KEY_ID_MIN + 893)
Public Const KEY_AXIS_PROPELLER4_SET = (KEY_ID_MIN + 894)
Public Const KEY_AXIS_MIXTURE4_SET = (KEY_ID_MIN + 895)
Public Const KEY_FLIGHT_MAP = (KEY_ID_MIN + 896)
Public Const KEY_LABEL_COLOR_CYCLE = (KEY_ID_MIN + 897)
Public Const KEY_COM_RADIO_FRACT_DEC_CARRY = (KEY_ID_MIN + 898)
Public Const KEY_COM_RADIO_FRACT_INC_CARRY = (KEY_ID_MIN + 899)
Public Const KEY_COM2_RADIO_WHOLE_DEC = (KEY_ID_MIN + 900)
Public Const KEY_COM2_RADIO_WHOLE_INC = (KEY_ID_MIN + 901)
Public Const KEY_COM2_RADIO_FRACT_DEC = (KEY_ID_MIN + 902)
Public Const KEY_COM2_RADIO_FRACT_DEC_CARRY = (KEY_ID_MIN + 903)
Public Const KEY_COM2_RADIO_FRACT_INC = (KEY_ID_MIN + 904)
Public Const KEY_COM2_RADIO_FRACT_INC_CARRY = (KEY_ID_MIN + 905)
Public Const KEY_COM2_RADIO_SET = (KEY_ID_MIN + 906)
Public Const KEY_COM2_STBY_RADIO_SET = (KEY_ID_MIN + 907)
Public Const KEY_COM2_RADIO_SWAP = (KEY_ID_MIN + 908)
Public Const KEY_NAV1_RADIO_FRACT_DEC_CARRY = (KEY_ID_MIN + 909)
Public Const KEY_NAV1_RADIO_FRACT_INC_CARRY = (KEY_ID_MIN + 910)
Public Const KEY_NAV1_STBY_SET = (KEY_ID_MIN + 911)
Public Const KEY_NAV1_RADIO_SWAP = (KEY_ID_MIN + 912)
Public Const KEY_NAV2_RADIO_FRACT_DEC_CARRY = (KEY_ID_MIN + 913)
Public Const KEY_NAV2_RADIO_FRACT_INC_CARRY = (KEY_ID_MIN + 914)
Public Const KEY_NAV2_STBY_SET = (KEY_ID_MIN + 915)
Public Const KEY_NAV2_RADIO_SWAP = (KEY_ID_MIN + 916)
Public Const KEY_ADF1_RADIO_TENTHS_DEC = (KEY_ID_MIN + 917)
Public Const KEY_ADF1_RADIO_TENTHS_INC = (KEY_ID_MIN + 918)
Public Const KEY_XPNDR_1000_DEC = (KEY_ID_MIN + 919)
Public Const KEY_XPNDR_100_DEC = (KEY_ID_MIN + 920)
Public Const KEY_XPNDR_10_DEC = (KEY_ID_MIN + 921)
Public Const KEY_XPNDR_1_DEC = (KEY_ID_MIN + 922)
Public Const KEY_XPNDR_DEC_CARRY = (KEY_ID_MIN + 923)
Public Const KEY_XPNDR_INC_CARRY = (KEY_ID_MIN + 924)
Public Const KEY_ADF_FRACT_DEC_CARRY = (KEY_ID_MIN + 925)
Public Const KEY_ADF_FRACT_INC_CARRY = (KEY_ID_MIN + 926)
Public Const KEY_COM1_TRANSMIT_SELECT = (KEY_ID_MIN + 927)
Public Const KEY_COM2_TRANSMIT_SELECT = (KEY_ID_MIN + 928)
Public Const KEY_COM_RECEIVE_ALL_TOGGLE = (KEY_ID_MIN + 929)
Public Const KEY_COM_RECEIVE_ALL_SET = (KEY_ID_MIN + 930)
Public Const KEY_MARKER_SOUND_TOGGLE = (KEY_ID_MIN + 941)
Public Const KEY_MARKER_SOUND_SET = (KEY_ID_MIN + 942)
Public Const KEY_ADF_COMPLETE_SET = (KEY_ID_MIN + 943)
Public Const KEY_ADF_OUTSIDE_SOURCE = (KEY_ID_MIN + 944)
Public Const KEY_ADF_NEEDLE_SET = (KEY_ID_MIN + 945)
Public Const KEY_TOGGLE_WATER_RUDDER = (KEY_ID_MIN + 946)
Public Const KEY_PUSHBACK_SET = (KEY_ID_MIN + 947)
Public Const KEY_ANTI_ICE_TOGGLE_ENG1 = (KEY_ID_MIN + 948)
Public Const KEY_ANTI_ICE_TOGGLE_ENG2 = (KEY_ID_MIN + 949)
Public Const KEY_ANTI_ICE_TOGGLE_ENG3 = (KEY_ID_MIN + 950)
Public Const KEY_ANTI_ICE_TOGGLE_ENG4 = (KEY_ID_MIN + 951)
Public Const KEY_ANTI_ICE_SET_ENG1 = (KEY_ID_MIN + 952)
Public Const KEY_ANTI_ICE_SET_ENG2 = (KEY_ID_MIN + 953)
Public Const KEY_ANTI_ICE_SET_ENG3 = (KEY_ID_MIN + 954)
Public Const KEY_ANTI_ICE_SET_ENG4 = (KEY_ID_MIN + 955)
Public Const KEY_RELOAD_PANELS = (KEY_ID_MIN + 956)
Public Const KEY_TOGGLE_FUEL_VALVE_ALL = (KEY_ID_MIN + 957)
Public Const KEY_TOGGLE_FUEL_VALVE_ENG1 = (KEY_ID_MIN + 958)
Public Const KEY_TOGGLE_FUEL_VALVE_ENG2 = (KEY_ID_MIN + 959)
Public Const KEY_TOGGLE_FUEL_VALVE_ENG3 = (KEY_ID_MIN + 960)
Public Const KEY_TOGGLE_FUEL_VALVE_ENG4 = (KEY_ID_MIN + 961)
Public Const KEY_TUG_HEADING = (KEY_ID_MIN + 962)
Public Const KEY_TUG_SPEED = (KEY_ID_MIN + 963)
Public Const KEY_CHASE_VIEW_NEXT = (KEY_ID_MIN + 964)
Public Const KEY_CHASE_VIEW_PREV = (KEY_ID_MIN + 965)
Public Const KEY_AP_NAV_SELECT_SET = (KEY_ID_MIN + 966)
Public Const KEY_AXIS_PAN_PITCH = (KEY_ID_MIN + 967)
Public Const KEY_AXIS_PAN_HEADING = (KEY_ID_MIN + 968)
Public Const KEY_AXIS_PAN_TILT = (KEY_ID_MIN + 969)
Public Const KEY_PANEL_ID_TOGGLE = (KEY_ID_MIN + 970)
Public Const KEY_PANEL_ID_OPEN = (KEY_ID_MIN + 971)
Public Const KEY_PANEL_ID_CLOSE = (KEY_ID_MIN + 972)
Public Const KEY_HEADING_BUG_SELECT = (KEY_ID_MIN + 973)
Public Const KEY_ALTITUDE_BUG_SELECT = (KEY_ID_MIN + 974)
Public Const KEY_VSI_BUG_SELECT = (KEY_ID_MIN + 975)
Public Const KEY_CONTROL_RELOAD_USER_AIRCRAFT = (KEY_ID_MIN + 976)
Public Const KEY_ATC_MENU_OPEN = (KEY_ID_MIN + 977)
Public Const KEY_ATC_MENU_CLOSE = (KEY_ID_MIN + 978)
Public Const KEY_CHASE_VIEW_TOGGLE = (KEY_ID_MIN + 979)
Public Const KEY_FUEL_SELECTOR_2_OFF = (KEY_ID_MIN + 980)
Public Const KEY_FUEL_SELECTOR_2_ALL = (KEY_ID_MIN + 981)
Public Const KEY_FUEL_SELECTOR_2_LEFT = (KEY_ID_MIN + 982)
Public Const KEY_FUEL_SELECTOR_2_RIGHT = (KEY_ID_MIN + 983)
Public Const KEY_FUEL_SELECTOR_2_LEFT_AUX = (KEY_ID_MIN + 984)
Public Const KEY_FUEL_SELECTOR_2_RIGHT_AUX = (KEY_ID_MIN + 985)
Public Const KEY_FUEL_SELECTOR_2_CENTER = (KEY_ID_MIN + 986)
Public Const KEY_FUEL_SELECTOR_2_SET = (KEY_ID_MIN + 987)
Public Const KEY_EYEPOINT_UP = (KEY_ID_MIN + 988)
Public Const KEY_EYEPOINT_DOWN = (KEY_ID_MIN + 989)
Public Const KEY_EYEPOINT_RIGHT = (KEY_ID_MIN + 990)
Public Const KEY_EYEPOINT_LEFT = (KEY_ID_MIN + 991)
Public Const KEY_EYEPOINT_FORWARD = (KEY_ID_MIN + 992)
Public Const KEY_EYEPOINT_BACK = (KEY_ID_MIN + 993)
Public Const KEY_EYEPOINT_RESET = (KEY_ID_MIN + 994)
Public Const KEY_ENGINE_AUTO_SHUTDOWN = (KEY_ID_MIN + 995)
Public Const KEY_AIRSPEED_BUG_SELECT = (KEY_ID_MIN + 996)
Public Const KEY_TUG_DISABLE = (KEY_ID_MIN + 997)
Public Const KEY_AXIS_FLAPS_SET = (KEY_ID_MIN + 998)
Public Const KEY_TOGGLE_MASTER_IGNITION_SWITCH = (KEY_ID_MIN + 999)
Public Const KEY_TOGGLE_FEATHER_SWITCHES = (KEY_ID_MIN + 1000)
Public Const KEY_TOGGLE_FEATHER_SWITCH_1 = (KEY_ID_MIN + 1001)
Public Const KEY_TOGGLE_FEATHER_SWITCH_2 = (KEY_ID_MIN + 1002)
Public Const KEY_TOGGLE_FEATHER_SWITCH_3 = (KEY_ID_MIN + 1003)
Public Const KEY_TOGGLE_FEATHER_SWITCH_4 = (KEY_ID_MIN + 1004)
Public Const KEY_TOGGLE_TAILWHEEL_LOCK = (KEY_ID_MIN + 1005)
Public Const KEY_ADF_WHOLE_INC = (KEY_ID_MIN + 1006)
Public Const KEY_ADF_WHOLE_DEC = (KEY_ID_MIN + 1007)
Public Const KEY_ADF2_100_INC = (KEY_ID_MIN + 1008)
Public Const KEY_ADF2_10_INC = (KEY_ID_MIN + 1009)
Public Const KEY_ADF2_1_INC = (KEY_ID_MIN + 1010)
Public Const KEY_ADF2_RADIO_TENTHS_INC = (KEY_ID_MIN + 1011)
Public Const KEY_ADF2_100_DEC = (KEY_ID_MIN + 1012)
Public Const KEY_ADF2_10_DEC = (KEY_ID_MIN + 1013)
Public Const KEY_ADF2_1_DEC = (KEY_ID_MIN + 1014)
Public Const KEY_ADF2_RADIO_TENTHS_DEC = (KEY_ID_MIN + 1015)
Public Const KEY_ADF2_WHOLE_INC = (KEY_ID_MIN + 1016)
Public Const KEY_ADF2_WHOLE_DEC = (KEY_ID_MIN + 1017)
Public Const KEY_ADF2_FRACT_INC_CARRY = (KEY_ID_MIN + 1018)
Public Const KEY_ADF2_FRACT_DEC_CARRY = (KEY_ID_MIN + 1019)
Public Const KEY_ADF2_COMPLETE_SET = (KEY_ID_MIN + 1020)
Public Const KEY_RADIO_ADF2_IDENT_DISABLE = (KEY_ID_MIN + 1021)
Public Const KEY_RADIO_ADF2_IDENT_ENABLE = (KEY_ID_MIN + 1022)
Public Const KEY_RADIO_ADF2_IDENT_TOGGLE = (KEY_ID_MIN + 1023)
Public Const KEY_RADIO_ADF2_IDENT_SET = (KEY_ID_MIN + 1024)
Public Const KEY_FUEL_SELECTOR_3_OFF = (KEY_ID_MIN + 1025)
Public Const KEY_FUEL_SELECTOR_3_ALL = (KEY_ID_MIN + 1026)
Public Const KEY_FUEL_SELECTOR_3_LEFT = (KEY_ID_MIN + 1027)
Public Const KEY_FUEL_SELECTOR_3_RIGHT = (KEY_ID_MIN + 1028)
Public Const KEY_FUEL_SELECTOR_3_LEFT_AUX = (KEY_ID_MIN + 1029)
Public Const KEY_FUEL_SELECTOR_3_RIGHT_AUX = (KEY_ID_MIN + 1030)
Public Const KEY_FUEL_SELECTOR_3_CENTER = (KEY_ID_MIN + 1031)
Public Const KEY_FUEL_SELECTOR_3_SET = (KEY_ID_MIN + 1032)
Public Const KEY_FUEL_SELECTOR_4_OFF = (KEY_ID_MIN + 1033)
Public Const KEY_FUEL_SELECTOR_4_ALL = (KEY_ID_MIN + 1034)
Public Const KEY_FUEL_SELECTOR_4_LEFT = (KEY_ID_MIN + 1035)
Public Const KEY_FUEL_SELECTOR_4_RIGHT = (KEY_ID_MIN + 1036)
Public Const KEY_FUEL_SELECTOR_4_LEFT_AUX = (KEY_ID_MIN + 1037)
Public Const KEY_FUEL_SELECTOR_4_RIGHT_AUX = (KEY_ID_MIN + 1038)
Public Const KEY_FUEL_SELECTOR_4_CENTER = (KEY_ID_MIN + 1039)
Public Const KEY_FUEL_SELECTOR_4_SET = (KEY_ID_MIN + 1040)
Public Const KEY_INDUCTOR_COMPASS_REF_INC = (KEY_ID_MIN + 1041)
Public Const KEY_INDUCTOR_COMPASS_REF_DEC = (KEY_ID_MIN + 1042)
Public Const KEY_TOGGLE_CABIN_LIGHTS = (KEY_ID_MIN + 1043)
Public Const KEY_RESET_G_FORCE_INDICATOR = (KEY_ID_MIN + 1044)
Public Const KEY_RESET_MAX_RPM_INDICATOR = (KEY_ID_MIN + 1045)
Public Const KEY_MANUAL_FUEL_TRANSFER = (KEY_ID_MIN + 1046)
Public Const KEY_AP_PITCH_REF_INC_UP = (KEY_ID_MIN + 1047)
Public Const KEY_AP_PITCH_REF_INC_DN = (KEY_ID_MIN + 1048)
Public Const KEY_AP_PITCH_REF_SELECT = (KEY_ID_MIN + 1049)
Public Const KEY_SIM_RESET = (KEY_ID_MIN + 1050)
Public Const KEY_ROTOR_BRAKE = (KEY_ID_MIN + 1051)
Public Const KEY_ROTOR_CLUTCH_SWITCH_TOGGLE = (KEY_ID_MIN + 1052)
Public Const KEY_ROTOR_CLUTCH_SWITCH_SET = (KEY_ID_MIN + 1053)
Public Const KEY_ROTOR_GOV_SWITCH_TOGGLE = (KEY_ID_MIN + 1054)
Public Const KEY_ROTOR_GOV_SWITCH_SET = (KEY_ID_MIN + 1055)
Public Const KEY_ROTOR_LATERAL_TRIM_INC = (KEY_ID_MIN + 1056)
Public Const KEY_ROTOR_LATERAL_TRIM_DEC = (KEY_ID_MIN + 1057)
Public Const KEY_ROTOR_LATERAL_TRIM_SET = (KEY_ID_MIN + 1058)
Public Const KEY_CROSS_FEED_OPEN = (KEY_ID_MIN + 1059)
Public Const KEY_CROSS_FEED_TOGGLE = (KEY_ID_MIN + 1060)
Public Const KEY_VIRTUAL_COPILOT_TOGGLE = (KEY_ID_MIN + 1061)
Public Const KEY_VIRTUAL_COPILOT_SET = (KEY_ID_MIN + 1062)
Public Const KEY_VIRTUAL_COPILOT_ACTION = (KEY_ID_MIN + 1063)
Public Const KEY_MIXTURE_SET_BEST = (KEY_ID_MIN + 1064)
Public Const KEY_ADD_FUEL_QUANTITY = (KEY_ID_MIN + 1065)
Public Const KEY_GPS_POWER_BUTTON = (KEY_ID_MIN + 1066)
Public Const KEY_GPS_NEAREST_BUTTON = (KEY_ID_MIN + 1068)
Public Const KEY_GPS_OBS_BUTTON = (KEY_ID_MIN + 1069)
Public Const KEY_GPS_MSG_BUTTON = (KEY_ID_MIN + 1070)
Public Const KEY_GPS_MSG_BUTTON_DOWN = (KEY_ID_MIN + 1071)
Public Const KEY_GPS_MSG_BUTTON_UP = (KEY_ID_MIN + 1072)
Public Const KEY_GPS_FLIGHTPLAN_BUTTON = (KEY_ID_MIN + 1073)
Public Const KEY_GPS_VNAV_BUTTON = (KEY_ID_MIN + 1074)
Public Const KEY_GPS_TERRAIN_BUTTON = (KEY_ID_MIN + 1075)
Public Const KEY_GPS_PROCEDURE_BUTTON = (KEY_ID_MIN + 1076)
Public Const KEY_GPS_SETUP_BUTTON = (KEY_ID_MIN + 1077)
Public Const KEY_GPS_ACTIVATE_BUTTON = (KEY_ID_MIN + 1078)
Public Const KEY_GPS_ZOOMIN_BUTTON = (KEY_ID_MIN + 1079)
Public Const KEY_GPS_ZOOMOUT_BUTTON = (KEY_ID_MIN + 1080)
Public Const KEY_GPS_DIRECTTO_BUTTON = (KEY_ID_MIN + 1081)
Public Const KEY_GPS_MENU_BUTTON = (KEY_ID_MIN + 1082)
Public Const KEY_GPS_CLEAR_BUTTON = (KEY_ID_MIN + 1083)
Public Const KEY_GPS_CLEAR_ALL_BUTTON = (KEY_ID_MIN + 1084)
Public Const KEY_GPS_CLEAR_BUTTON_DOWN = (KEY_ID_MIN + 1085)
Public Const KEY_GPS_CLEAR_BUTTON_UP = (KEY_ID_MIN + 1086)
Public Const KEY_GPS_ENTER_BUTTON = (KEY_ID_MIN + 1087)
Public Const KEY_GPS_CURSOR_BUTTON = (KEY_ID_MIN + 1088)
Public Const KEY_GPS_GROUP_KNOB_INC = (KEY_ID_MIN + 1089)
Public Const KEY_GPS_GROUP_KNOB_DEC = (KEY_ID_MIN + 1090)
Public Const KEY_GPS_PAGE_KNOB_INC = (KEY_ID_MIN + 1091)
Public Const KEY_GPS_PAGE_KNOB_DEC = (KEY_ID_MIN + 1092)
Public Const KEY_GPS_BUTTON1 = (KEY_ID_MIN + 1093)
Public Const KEY_GPS_BUTTON2 = (KEY_ID_MIN + 1094)
Public Const KEY_GPS_BUTTON3 = (KEY_ID_MIN + 1095)
Public Const KEY_GPS_BUTTON4 = (KEY_ID_MIN + 1096)
Public Const KEY_GPS_BUTTON5 = (KEY_ID_MIN + 1097)
Public Const KEY_THROTTLE_DECR_SMALL = (KEY_ID_MIN + 1098)
Public Const KEY_THROTTLE1_DECR_SMALL = (KEY_ID_MIN + 1099)
Public Const KEY_THROTTLE2_DECR_SMALL = (KEY_ID_MIN + 1100)
Public Const KEY_THROTTLE3_DECR_SMALL = (KEY_ID_MIN + 1101)
Public Const KEY_THROTTLE4_DECR_SMALL = (KEY_ID_MIN + 1102)
Public Const KEY_PROP_PITCH_DECR_SMALL = (KEY_ID_MIN + 1103)
Public Const KEY_PROP_PITCH1_DECR_SMALL = (KEY_ID_MIN + 1104)
Public Const KEY_PROP_PITCH2_DECR_SMALL = (KEY_ID_MIN + 1105)
Public Const KEY_PROP_PITCH3_DECR_SMALL = (KEY_ID_MIN + 1106)
Public Const KEY_PROP_PITCH4_DECR_SMALL = (KEY_ID_MIN + 1107)
Public Const KEY_MIXTURE_DECR_SMALL = (KEY_ID_MIN + 1108)
Public Const KEY_MIXTURE1_DECR_SMALL = (KEY_ID_MIN + 1109)
Public Const KEY_MIXTURE2_DECR_SMALL = (KEY_ID_MIN + 1110)
Public Const KEY_MIXTURE3_DECR_SMALL = (KEY_ID_MIN + 1111)
Public Const KEY_MIXTURE4_DECR_SMALL = (KEY_ID_MIN + 1112)


